# type: ignore
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import api_options_pb2 as api__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tapi.proto\x1a\x11\x61pi_options.proto\"d\n\x0cHelloRequest\x12\x13\n\x0b\x63lient_info\x18\x01 \x01(\t\x12\x19\n\x11\x61pi_version_major\x18\x02 \x01(\r\x12\x19\n\x11\x61pi_version_minor\x18\x03 \x01(\r:\t\xe0@\x01\xe8@\x02\x80\x41\x01\"s\n\rHelloResponse\x12\x19\n\x11\x61pi_version_major\x18\x01 \x01(\r\x12\x19\n\x11\x61pi_version_minor\x18\x02 \x01(\r\x12\x13\n\x0bserver_info\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t:\t\xe0@\x02\xe8@\x01\x80\x41\x01\"6\n\x15\x41uthenticationRequest\x12\x10\n\x08password\x18\x01 \x01(\t:\x0b\x18\x01\xe0@\x03\xe8@\x02\x80\x41\x01\"?\n\x16\x41uthenticationResponse\x12\x18\n\x10invalid_password\x18\x01 \x01(\x08:\x0b\x18\x01\xe0@\x04\xe8@\x01\x80\x41\x01\"\x1e\n\x11\x44isconnectRequest:\t\xe0@\x05\xe8@\x00\x80\x41\x01\"\x1f\n\x12\x44isconnectResponse:\t\xe0@\x06\xe8@\x00\x80\x41\x01\"\x15\n\x0bPingRequest:\x06\xe0@\x07\xe8@\x00\"\x16\n\x0cPingResponse:\x06\xe0@\x08\xe8@\x00\"\x1b\n\x11\x44\x65viceInfoRequest:\x06\xe0@\t\xe8@\x02\")\n\x08\x41reaInfo\x12\x0f\n\x07\x61rea_id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\">\n\nDeviceInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x61rea_id\x18\x03 \x01(\r\"H\n\x0fSerialProxyInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\'\n\tport_type\x18\x02 \x01(\x0e\x32\x14.SerialProxyPortType\"\xf4\x08\n\x12\x44\x65viceInfoResponse\x12\x19\n\ruses_password\x18\x01 \x01(\x08\x42\x02\x18\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bmac_address\x18\x03 \x01(\t\x12\x17\n\x0f\x65sphome_version\x18\x04 \x01(\t\x12\x18\n\x10\x63ompilation_time\x18\x05 \x01(\t\x12\r\n\x05model\x18\x06 \x01(\t\x12)\n\x0ehas_deep_sleep\x18\x07 \x01(\x08\x42\x11\x92\x41\x0eUSE_DEEP_SLEEP\x12-\n\x0cproject_name\x18\x08 \x01(\tB\x17\x92\x41\x14\x45SPHOME_PROJECT_NAME\x12\x30\n\x0fproject_version\x18\t \x01(\tB\x17\x92\x41\x14\x45SPHOME_PROJECT_NAME\x12(\n\x0ewebserver_port\x18\n \x01(\rB\x10\x92\x41\rUSE_WEBSERVER\x12@\n\x1elegacy_bluetooth_proxy_version\x18\x0b \x01(\rB\x18\x18\x01\x92\x41\x13USE_BLUETOOTH_PROXY\x12=\n\x1d\x62luetooth_proxy_feature_flags\x18\x0f \x01(\rB\x16\x92\x41\x13USE_BLUETOOTH_PROXY\x12\x14\n\x0cmanufacturer\x18\x0c \x01(\t\x12\x15\n\rfriendly_name\x18\r \x01(\t\x12@\n\x1elegacy_voice_assistant_version\x18\x0e \x01(\rB\x18\x18\x01\x92\x41\x13USE_VOICE_ASSISTANT\x12=\n\x1dvoice_assistant_feature_flags\x18\x11 \x01(\rB\x16\x92\x41\x13USE_VOICE_ASSISTANT\x12$\n\x0esuggested_area\x18\x10 \x01(\tB\x0c\x92\x41\tUSE_AREAS\x12\x35\n\x15\x62luetooth_mac_address\x18\x12 \x01(\tB\x16\x92\x41\x13USE_BLUETOOTH_PROXY\x12\x32\n\x18\x61pi_encryption_supported\x18\x13 \x01(\x08\x42\x10\x92\x41\rUSE_API_NOISE\x12\x44\n\x07\x64\x65vices\x18\x14 \x03(\x0b\x32\x0b.DeviceInfoB&\x92\x41\x0bUSE_DEVICES\xd2\xb5\x18\x14\x45SPHOME_DEVICE_COUNT\x12<\n\x05\x61reas\x18\x15 \x03(\x0b\x32\t.AreaInfoB\"\x92\x41\tUSE_AREAS\xd2\xb5\x18\x12\x45SPHOME_AREA_COUNT\x12%\n\x04\x61rea\x18\x16 \x01(\x0b\x32\t.AreaInfoB\x0c\x92\x41\tUSE_AREAS\x12\x35\n\x19zwave_proxy_feature_flags\x18\x17 \x01(\rB\x12\x92\x41\x0fUSE_ZWAVE_PROXY\x12)\n\rzwave_home_id\x18\x18 \x01(\rB\x12\x92\x41\x0fUSE_ZWAVE_PROXY\x12S\n\x0eserial_proxies\x18\x19 \x03(\x0b\x32\x10.SerialProxyInfoB)\x92\x41\x10USE_SERIAL_PROXY\xd2\xb5\x18\x12SERIAL_PROXY_COUNT:\x06\xe0@\n\xe8@\x01\"\x1d\n\x13ListEntitiesRequest:\x06\xe0@\x0b\xe8@\x02\"%\n\x18ListEntitiesDoneResponse:\t\xe0@\x13\xe8@\x01\x80\x41\x01\" \n\x16SubscribeStatesRequest:\x06\xe0@\x14\xe8@\x02\"\xd6\x02\n ListEntitiesBinarySensorResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0c\x64\x65vice_class\x18\x05 \x01(\t\x12\x1f\n\x17is_status_binary_sensor\x18\x06 \x01(\x08\x12\x1b\n\x13\x64isabled_by_default\x18\x07 \x01(\x08\x12 \n\x04icon\x18\x08 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12(\n\x0f\x65ntity_category\x18\t \x01(\x0e\x32\x0f.EntityCategory\x12!\n\tdevice_id\x18\n \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:5\xe0@\x0c\xe8@\x01\xf2@\x11USE_BINARY_SENSOR\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\xb2\x01\n\x19\x42inarySensorStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\r\n\x05state\x18\x02 \x01(\x08\x12\x15\n\rmissing_state\x18\x03 \x01(\x08\x12!\n\tdevice_id\x18\x04 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:9\xe0@\x15\xe8@\x01\xf2@\x11USE_BINARY_SENSOR\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\x86\x03\n\x19ListEntitiesCoverResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x15\n\rassumed_state\x18\x05 \x01(\x08\x12\x19\n\x11supports_position\x18\x06 \x01(\x08\x12\x15\n\rsupports_tilt\x18\x07 \x01(\x08\x12\x14\n\x0c\x64\x65vice_class\x18\x08 \x01(\t\x12\x1b\n\x13\x64isabled_by_default\x18\t \x01(\x08\x12 \n\x04icon\x18\n \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12(\n\x0f\x65ntity_category\x18\x0b \x01(\x0e\x32\x0f.EntityCategory\x12\x15\n\rsupports_stop\x18\x0c \x01(\x08\x12!\n\tdevice_id\x18\r \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:-\xe0@\r\xe8@\x01\xf2@\tUSE_COVER\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\xf6\x01\n\x12\x43overStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12+\n\x0clegacy_state\x18\x02 \x01(\x0e\x32\x11.LegacyCoverStateB\x02\x18\x01\x12\x10\n\x08position\x18\x03 \x01(\x02\x12\x0c\n\x04tilt\x18\x04 \x01(\x02\x12*\n\x11\x63urrent_operation\x18\x05 \x01(\x0e\x32\x0f.CoverOperation\x12!\n\tdevice_id\x18\x06 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:1\xe0@\x16\xe8@\x01\xf2@\tUSE_COVER\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\x9f\x02\n\x13\x43overCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x1e\n\x12has_legacy_command\x18\x02 \x01(\x08\x42\x02\x18\x01\x12/\n\x0elegacy_command\x18\x03 \x01(\x0e\x32\x13.LegacyCoverCommandB\x02\x18\x01\x12\x14\n\x0chas_position\x18\x04 \x01(\x08\x12\x10\n\x08position\x18\x05 \x01(\x02\x12\x10\n\x08has_tilt\x18\x06 \x01(\x08\x12\x0c\n\x04tilt\x18\x07 \x01(\x02\x12\x0c\n\x04stop\x18\x08 \x01(\x08\x12!\n\tdevice_id\x18\t \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:+\xe0@\x1e\xe8@\x02\xf2@\tUSE_COVER\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"\xbc\x03\n\x17ListEntitiesFanResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1c\n\x14supports_oscillation\x18\x05 \x01(\x08\x12\x16\n\x0esupports_speed\x18\x06 \x01(\x08\x12\x1a\n\x12supports_direction\x18\x07 \x01(\x08\x12\x1d\n\x15supported_speed_count\x18\x08 \x01(\x05\x12\x1b\n\x13\x64isabled_by_default\x18\t \x01(\x08\x12 \n\x04icon\x18\n \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12(\n\x0f\x65ntity_category\x18\x0b \x01(\x0e\x32\x0f.EntityCategory\x12=\n\x16supported_preset_modes\x18\x0c \x03(\tB\x1d\xf2\xb5\x18\x19std::vector<const char *>\x12!\n\tdevice_id\x18\r \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:+\xe0@\x0e\xe8@\x01\xf2@\x07USE_FAN\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\x87\x02\n\x10\x46\x61nStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\r\n\x05state\x18\x02 \x01(\x08\x12\x13\n\x0boscillating\x18\x03 \x01(\x08\x12\x1c\n\x05speed\x18\x04 \x01(\x0e\x32\t.FanSpeedB\x02\x18\x01\x12 \n\tdirection\x18\x05 \x01(\x0e\x32\r.FanDirection\x12\x13\n\x0bspeed_level\x18\x06 \x01(\x05\x12\x13\n\x0bpreset_mode\x18\x07 \x01(\t\x12!\n\tdevice_id\x18\x08 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:/\xe0@\x17\xe8@\x01\xf2@\x07USE_FAN\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\x8e\x03\n\x11\x46\x61nCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x11\n\thas_state\x18\x02 \x01(\x08\x12\r\n\x05state\x18\x03 \x01(\x08\x12\x15\n\thas_speed\x18\x04 \x01(\x08\x42\x02\x18\x01\x12\x1c\n\x05speed\x18\x05 \x01(\x0e\x32\t.FanSpeedB\x02\x18\x01\x12\x17\n\x0fhas_oscillating\x18\x06 \x01(\x08\x12\x13\n\x0boscillating\x18\x07 \x01(\x08\x12\x15\n\rhas_direction\x18\x08 \x01(\x08\x12 \n\tdirection\x18\t \x01(\x0e\x32\r.FanDirection\x12\x17\n\x0fhas_speed_level\x18\n \x01(\x08\x12\x13\n\x0bspeed_level\x18\x0b \x01(\x05\x12\x17\n\x0fhas_preset_mode\x18\x0c \x01(\x08\x12\x13\n\x0bpreset_mode\x18\r \x01(\t\x12!\n\tdevice_id\x18\x0e \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:)\xe0@\x1f\xe8@\x02\xf2@\x07USE_FAN\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"\xce\x04\n\x19ListEntitiesLightResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x43\n\x15supported_color_modes\x18\x0c \x03(\x0e\x32\n.ColorModeB\x18\xf2\xb5\x18\x14light::ColorModeMask\x12&\n\x1alegacy_supports_brightness\x18\x05 \x01(\x08\x42\x02\x18\x01\x12\x1f\n\x13legacy_supports_rgb\x18\x06 \x01(\x08\x42\x02\x18\x01\x12\'\n\x1blegacy_supports_white_value\x18\x07 \x01(\x08\x42\x02\x18\x01\x12-\n!legacy_supports_color_temperature\x18\x08 \x01(\x08\x42\x02\x18\x01\x12\x12\n\nmin_mireds\x18\t \x01(\x02\x12\x12\n\nmax_mireds\x18\n \x01(\x02\x12.\n\x07\x65\x66\x66\x65\x63ts\x18\x0b \x03(\tB\x1d\xf2\xb5\x18\x19\x46ixedVector<const char *>\x12\x1b\n\x13\x64isabled_by_default\x18\r \x01(\x08\x12 \n\x04icon\x18\x0e \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12(\n\x0f\x65ntity_category\x18\x0f \x01(\x0e\x32\x0f.EntityCategory\x12!\n\tdevice_id\x18\x10 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:-\xe0@\x0f\xe8@\x01\xf2@\tUSE_LIGHT\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\xe6\x02\n\x12LightStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\r\n\x05state\x18\x02 \x01(\x08\x12\x12\n\nbrightness\x18\x03 \x01(\x02\x12\x1e\n\ncolor_mode\x18\x0b \x01(\x0e\x32\n.ColorMode\x12\x18\n\x10\x63olor_brightness\x18\n \x01(\x02\x12\x0b\n\x03red\x18\x04 \x01(\x02\x12\r\n\x05green\x18\x05 \x01(\x02\x12\x0c\n\x04\x62lue\x18\x06 \x01(\x02\x12\r\n\x05white\x18\x07 \x01(\x02\x12\x19\n\x11\x63olor_temperature\x18\x08 \x01(\x02\x12\x12\n\ncold_white\x18\x0c \x01(\x02\x12\x12\n\nwarm_white\x18\r \x01(\x02\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\t \x01(\t\x12!\n\tdevice_id\x18\x0e \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:1\xe0@\x18\xe8@\x01\xf2@\tUSE_LIGHT\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\xb3\x05\n\x13LightCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x11\n\thas_state\x18\x02 \x01(\x08\x12\r\n\x05state\x18\x03 \x01(\x08\x12\x16\n\x0ehas_brightness\x18\x04 \x01(\x08\x12\x12\n\nbrightness\x18\x05 \x01(\x02\x12\x16\n\x0ehas_color_mode\x18\x16 \x01(\x08\x12\x1e\n\ncolor_mode\x18\x17 \x01(\x0e\x32\n.ColorMode\x12\x1c\n\x14has_color_brightness\x18\x14 \x01(\x08\x12\x18\n\x10\x63olor_brightness\x18\x15 \x01(\x02\x12\x0f\n\x07has_rgb\x18\x06 \x01(\x08\x12\x0b\n\x03red\x18\x07 \x01(\x02\x12\r\n\x05green\x18\x08 \x01(\x02\x12\x0c\n\x04\x62lue\x18\t \x01(\x02\x12\x11\n\thas_white\x18\n \x01(\x08\x12\r\n\x05white\x18\x0b \x01(\x02\x12\x1d\n\x15has_color_temperature\x18\x0c \x01(\x08\x12\x19\n\x11\x63olor_temperature\x18\r \x01(\x02\x12\x16\n\x0ehas_cold_white\x18\x18 \x01(\x08\x12\x12\n\ncold_white\x18\x19 \x01(\x02\x12\x16\n\x0ehas_warm_white\x18\x1a \x01(\x08\x12\x12\n\nwarm_white\x18\x1b \x01(\x02\x12\x1d\n\x15has_transition_length\x18\x0e \x01(\x08\x12\x19\n\x11transition_length\x18\x0f \x01(\r\x12\x18\n\x10has_flash_length\x18\x10 \x01(\x08\x12\x14\n\x0c\x66lash_length\x18\x11 \x01(\r\x12\x12\n\nhas_effect\x18\x12 \x01(\x08\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\x13 \x01(\t\x12!\n\tdevice_id\x18\x1c \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:+\xe0@ \xe8@\x02\xf2@\tUSE_LIGHT\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"\xd8\x03\n\x1aListEntitiesSensorResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x05 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x1b\n\x13unit_of_measurement\x18\x06 \x01(\t\x12\x19\n\x11\x61\x63\x63uracy_decimals\x18\x07 \x01(\x05\x12\x14\n\x0c\x66orce_update\x18\x08 \x01(\x08\x12\x14\n\x0c\x64\x65vice_class\x18\t \x01(\t\x12&\n\x0bstate_class\x18\n \x01(\x0e\x32\x11.SensorStateClass\x12\x38\n\x16legacy_last_reset_type\x18\x0b \x01(\x0e\x32\x14.SensorLastResetTypeB\x02\x18\x01\x12\x1b\n\x13\x64isabled_by_default\x18\x0c \x01(\x08\x12(\n\x0f\x65ntity_category\x18\r \x01(\x0e\x32\x0f.EntityCategory\x12!\n\tdevice_id\x18\x0e \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:.\xe0@\x10\xe8@\x01\xf2@\nUSE_SENSOR\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\xa5\x01\n\x13SensorStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\r\n\x05state\x18\x02 \x01(\x02\x12\x15\n\rmissing_state\x18\x03 \x01(\x08\x12!\n\tdevice_id\x18\x04 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:2\xe0@\x19\xe8@\x01\xf2@\nUSE_SENSOR\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\xbf\x02\n\x1aListEntitiesSwitchResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x05 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x15\n\rassumed_state\x18\x06 \x01(\x08\x12\x1b\n\x13\x64isabled_by_default\x18\x07 \x01(\x08\x12(\n\x0f\x65ntity_category\x18\x08 \x01(\x0e\x32\x0f.EntityCategory\x12\x14\n\x0c\x64\x65vice_class\x18\t \x01(\t\x12!\n\tdevice_id\x18\n \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:.\xe0@\x11\xe8@\x01\xf2@\nUSE_SWITCH\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\x8e\x01\n\x13SwitchStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\r\n\x05state\x18\x02 \x01(\x08\x12!\n\tdevice_id\x18\x03 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:2\xe0@\x1a\xe8@\x01\xf2@\nUSE_SWITCH\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\x89\x01\n\x14SwitchCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\r\n\x05state\x18\x02 \x01(\x08\x12!\n\tdevice_id\x18\x03 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:,\xe0@!\xe8@\x02\xf2@\nUSE_SWITCH\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"\xb1\x02\n\x1eListEntitiesTextSensorResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x05 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x1b\n\x13\x64isabled_by_default\x18\x06 \x01(\x08\x12(\n\x0f\x65ntity_category\x18\x07 \x01(\x0e\x32\x0f.EntityCategory\x12\x14\n\x0c\x64\x65vice_class\x18\x08 \x01(\t\x12!\n\tdevice_id\x18\t \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:3\xe0@\x12\xe8@\x01\xf2@\x0fUSE_TEXT_SENSOR\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\xae\x01\n\x17TextSensorStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\r\n\x05state\x18\x02 \x01(\t\x12\x15\n\rmissing_state\x18\x03 \x01(\x08\x12!\n\tdevice_id\x18\x04 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:7\xe0@\x1b\xe8@\x01\xf2@\x0fUSE_TEXT_SENSOR\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"M\n\x14SubscribeLogsRequest\x12\x18\n\x05level\x18\x01 \x01(\x0e\x32\t.LogLevel\x12\x13\n\x0b\x64ump_config\x18\x02 \x01(\x08:\x06\xe0@\x1c\xe8@\x02\"P\n\x15SubscribeLogsResponse\x12\x18\n\x05level\x18\x01 \x01(\x0e\x32\t.LogLevel\x12\x0f\n\x07message\x18\x03 \x01(\x0c:\x0c\xe0@\x1d\xe8@\x01\xf8@\x00\x80\x41\x00\"C\n\x1cNoiseEncryptionSetKeyRequest\x12\x0b\n\x03key\x18\x01 \x01(\x0c:\x16\xe0@|\xe8@\x02\xf2@\rUSE_API_NOISE\"H\n\x1dNoiseEncryptionSetKeyResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08:\x16\xe0@}\xe8@\x01\xf2@\rUSE_API_NOISE\"P\n%SubscribeHomeassistantServicesRequest:\'\xe0@\"\xe8@\x02\xf2@\x1eUSE_API_HOMEASSISTANT_SERVICES\"5\n\x17HomeassistantServiceMap\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xd2\x03\n\x1aHomeassistantActionRequest\x12\x0f\n\x07service\x18\x01 \x01(\t\x12,\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x18.HomeassistantServiceMapB\x04\xe8\xb5\x18\x01\x12\x35\n\rdata_template\x18\x03 \x03(\x0b\x32\x18.HomeassistantServiceMapB\x04\xe8\xb5\x18\x01\x12\x31\n\tvariables\x18\x04 \x03(\x0b\x32\x18.HomeassistantServiceMapB\x04\xe8\xb5\x18\x01\x12\x10\n\x08is_event\x18\x05 \x01(\x08\x12:\n\x07\x63\x61ll_id\x18\x06 \x01(\rB)\x92\x41&USE_API_HOMEASSISTANT_ACTION_RESPONSES\x12\x46\n\x0ewants_response\x18\x07 \x01(\x08\x42.\x92\x41+USE_API_HOMEASSISTANT_ACTION_RESPONSES_JSON\x12I\n\x11response_template\x18\x08 \x01(\tB.\x92\x41+USE_API_HOMEASSISTANT_ACTION_RESPONSES_JSON:*\xe0@#\xe8@\x01\xf2@\x1eUSE_API_HOMEASSISTANT_SERVICES\x80\x41\x01\"\xd2\x01\n\x1bHomeassistantActionResponse\x12\x0f\n\x07\x63\x61ll_id\x18\x01 \x01(\r\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\x12\x45\n\rresponse_data\x18\x04 \x01(\x0c\x42.\x92\x41+USE_API_HOMEASSISTANT_ACTION_RESPONSES_JSON:3\xe0@\x82\x01\xe8@\x02\xf2@&USE_API_HOMEASSISTANT_ACTION_RESPONSES\x80\x41\x01\"L\n#SubscribeHomeAssistantStatesRequest:%\xe0@&\xe8@\x02\xf2@\x1cUSE_API_HOMEASSISTANT_STATES\"\x80\x01\n#SubscribeHomeAssistantStateResponse\x12\x11\n\tentity_id\x18\x01 \x01(\t\x12\x11\n\tattribute\x18\x02 \x01(\t\x12\x0c\n\x04once\x18\x03 \x01(\x08:%\xe0@\'\xe8@\x01\xf2@\x1cUSE_API_HOMEASSISTANT_STATES\"{\n\x1aHomeAssistantStateResponse\x12\x11\n\tentity_id\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\x12\x11\n\tattribute\x18\x03 \x01(\t:(\xe0@(\xe8@\x02\xf2@\x1cUSE_API_HOMEASSISTANT_STATES\x80\x41\x01\"\x18\n\x0eGetTimeRequest:\x06\xe0@$\xe8@\x01\"\x7f\n\x07\x44STRule\x12\x14\n\x0ctime_seconds\x18\x01 \x01(\x11\x12\x0b\n\x03\x64\x61y\x18\x02 \x01(\r\x12\x1a\n\x04type\x18\x03 \x01(\x0e\x32\x0c.DSTRuleType\x12\r\n\x05month\x18\x04 \x01(\r\x12\x0c\n\x04week\x18\x05 \x01(\r\x12\x13\n\x0b\x64\x61y_of_week\x18\x06 \x01(\r:\x03\xe8@\x02\"\x85\x01\n\x0eParsedTimezone\x12\x1a\n\x12std_offset_seconds\x18\x01 \x01(\x11\x12\x1a\n\x12\x64st_offset_seconds\x18\x02 \x01(\x11\x12\x1b\n\tdst_start\x18\x03 \x01(\x0b\x32\x08.DSTRule\x12\x19\n\x07\x64st_end\x18\x04 \x01(\x0b\x32\x08.DSTRule:\x03\xe8@\x02\"o\n\x0fGetTimeResponse\x12\x15\n\repoch_seconds\x18\x01 \x01(\x07\x12\x10\n\x08timezone\x18\x02 \x01(\t\x12(\n\x0fparsed_timezone\x18\x03 \x01(\x0b\x32\x0f.ParsedTimezone:\t\xe0@%\xe8@\x02\x80\x41\x01\"l\n\x1cListEntitiesServicesArgument\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1d\n\x04type\x18\x02 \x01(\x0e\x32\x0f.ServiceArgType:\x1f\xf2@\x1cUSE_API_USER_DEFINED_ACTIONS\"\xcb\x01\n\x1cListEntitiesServicesResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x31\n\x04\x61rgs\x18\x03 \x03(\x0b\x32\x1d.ListEntitiesServicesArgumentB\x04\xe8\xb5\x18\x01\x12\x30\n\x11supports_response\x18\x04 \x01(\x0e\x32\x15.SupportsResponseType:%\xe0@)\xe8@\x01\xf2@\x1cUSE_API_USER_DEFINED_ACTIONS\"\xfb\x01\n\x16\x45xecuteServiceArgument\x12\r\n\x05\x62ool_\x18\x01 \x01(\x08\x12\x12\n\nlegacy_int\x18\x02 \x01(\x05\x12\x0e\n\x06\x66loat_\x18\x03 \x01(\x02\x12\x0f\n\x07string_\x18\x04 \x01(\t\x12\x0c\n\x04int_\x18\x05 \x01(\x11\x12\x1a\n\nbool_array\x18\x06 \x03(\x08\x42\x06\x10\x00\xe8\xb5\x18\x01\x12\x19\n\tint_array\x18\x07 \x03(\x11\x42\x06\x10\x00\xe8\xb5\x18\x01\x12\x1b\n\x0b\x66loat_array\x18\x08 \x03(\x02\x42\x06\x10\x00\xe8\xb5\x18\x01\x12\x1a\n\x0cstring_array\x18\t \x03(\tB\x04\xe8\xb5\x18\x01:\x1f\xf2@\x1cUSE_API_USER_DEFINED_ACTIONS\"\xff\x01\n\x15\x45xecuteServiceRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12+\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x17.ExecuteServiceArgumentB\x04\xe8\xb5\x18\x01\x12\x39\n\x07\x63\x61ll_id\x18\x03 \x01(\rB(\x92\x41%USE_API_USER_DEFINED_ACTION_RESPONSES\x12\x41\n\x0freturn_response\x18\x04 \x01(\x08\x42(\x92\x41%USE_API_USER_DEFINED_ACTION_RESPONSES:(\xe0@*\xe8@\x02\xf2@\x1cUSE_API_USER_DEFINED_ACTIONS\x80\x41\x01\"\xcf\x01\n\x16\x45xecuteServiceResponse\x12\x0f\n\x07\x63\x61ll_id\x18\x01 \x01(\r\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\x12H\n\rresponse_data\x18\x04 \x01(\x0c\x42\x31\x92\x41*USE_API_USER_DEFINED_ACTION_RESPONSES_JSON\xe0\xb5\x18\x01:2\xe0@\x83\x01\xe8@\x01\xf2@%USE_API_USER_DEFINED_ACTION_RESPONSES\x80\x41\x01\"\x92\x02\n\x1aListEntitiesCameraResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1b\n\x13\x64isabled_by_default\x18\x05 \x01(\x08\x12 \n\x04icon\x18\x06 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12(\n\x0f\x65ntity_category\x18\x07 \x01(\x0e\x32\x0f.EntityCategory\x12!\n\tdevice_id\x18\x08 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:.\xe0@+\xe8@\x01\xf2@\nUSE_CAMERA\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\x98\x01\n\x13\x43\x61meraImageResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0c\n\x04\x64one\x18\x03 \x01(\x08\x12!\n\tdevice_id\x18\x04 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:/\xe0@,\xe8@\x01\xf2@\nUSE_CAMERA\x8a\x41\x19StateResponseProtoMessage\"L\n\x12\x43\x61meraImageRequest\x12\x0e\n\x06single\x18\x01 \x01(\x08\x12\x0e\n\x06stream\x18\x02 \x01(\x08:\x16\xe0@-\xe8@\x02\xf2@\nUSE_CAMERA\x80\x41\x01\"\x83\t\n\x1bListEntitiesClimateResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12$\n\x1csupports_current_temperature\x18\x05 \x01(\x08\x12-\n%supports_two_point_target_temperature\x18\x06 \x01(\x08\x12\x43\n\x0fsupported_modes\x18\x07 \x03(\x0e\x32\x0c.ClimateModeB\x1c\xf2\xb5\x18\x18\x63limate::ClimateModeMask\x12\x1e\n\x16visual_min_temperature\x18\x08 \x01(\x02\x12\x1e\n\x16visual_max_temperature\x18\t \x01(\x02\x12&\n\x1evisual_target_temperature_step\x18\n \x01(\x02\x12 \n\x14legacy_supports_away\x18\x0b \x01(\x08\x42\x02\x18\x01\x12\x17\n\x0fsupports_action\x18\x0c \x01(\x08\x12M\n\x13supported_fan_modes\x18\r \x03(\x0e\x32\x0f.ClimateFanModeB\x1f\xf2\xb5\x18\x1b\x63limate::ClimateFanModeMask\x12S\n\x15supported_swing_modes\x18\x0e \x03(\x0e\x32\x11.ClimateSwingModeB!\xf2\xb5\x18\x1d\x63limate::ClimateSwingModeMask\x12\x41\n\x1asupported_custom_fan_modes\x18\x0f \x03(\tB\x1d\xf2\xb5\x18\x19std::vector<const char *>\x12I\n\x11supported_presets\x18\x10 \x03(\x0e\x32\x0e.ClimatePresetB\x1e\xf2\xb5\x18\x1a\x63limate::ClimatePresetMask\x12?\n\x18supported_custom_presets\x18\x11 \x03(\tB\x1d\xf2\xb5\x18\x19std::vector<const char *>\x12\x1b\n\x13\x64isabled_by_default\x18\x12 \x01(\x08\x12 \n\x04icon\x18\x13 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12(\n\x0f\x65ntity_category\x18\x14 \x01(\x0e\x32\x0f.EntityCategory\x12\'\n\x1fvisual_current_temperature_step\x18\x15 \x01(\x02\x12!\n\x19supports_current_humidity\x18\x16 \x01(\x08\x12 \n\x18supports_target_humidity\x18\x17 \x01(\x08\x12\x1b\n\x13visual_min_humidity\x18\x18 \x01(\x02\x12\x1b\n\x13visual_max_humidity\x18\x19 \x01(\x02\x12!\n\tdevice_id\x18\x1a \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES\x12\x15\n\rfeature_flags\x18\x1b \x01(\r:/\xe0@.\xe8@\x01\xf2@\x0bUSE_CLIMATE\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\xa4\x04\n\x14\x43limateStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x1a\n\x04mode\x18\x02 \x01(\x0e\x32\x0c.ClimateMode\x12\x1b\n\x13\x63urrent_temperature\x18\x03 \x01(\x02\x12\x1a\n\x12target_temperature\x18\x04 \x01(\x02\x12\x1e\n\x16target_temperature_low\x18\x05 \x01(\x02\x12\x1f\n\x17target_temperature_high\x18\x06 \x01(\x02\x12\x1e\n\x12unused_legacy_away\x18\x07 \x01(\x08\x42\x02\x18\x01\x12\x1e\n\x06\x61\x63tion\x18\x08 \x01(\x0e\x32\x0e.ClimateAction\x12!\n\x08\x66\x61n_mode\x18\t \x01(\x0e\x32\x0f.ClimateFanMode\x12%\n\nswing_mode\x18\n \x01(\x0e\x32\x11.ClimateSwingMode\x12\x17\n\x0f\x63ustom_fan_mode\x18\x0b \x01(\t\x12\x1e\n\x06preset\x18\x0c \x01(\x0e\x32\x0e.ClimatePreset\x12\x15\n\rcustom_preset\x18\r \x01(\t\x12\x18\n\x10\x63urrent_humidity\x18\x0e \x01(\x02\x12\x17\n\x0ftarget_humidity\x18\x0f \x01(\x02\x12!\n\tdevice_id\x18\x10 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:3\xe0@/\xe8@\x01\xf2@\x0bUSE_CLIMATE\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\xfe\x05\n\x15\x43limateCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x10\n\x08has_mode\x18\x02 \x01(\x08\x12\x1a\n\x04mode\x18\x03 \x01(\x0e\x32\x0c.ClimateMode\x12\x1e\n\x16has_target_temperature\x18\x04 \x01(\x08\x12\x1a\n\x12target_temperature\x18\x05 \x01(\x02\x12\"\n\x1ahas_target_temperature_low\x18\x06 \x01(\x08\x12\x1e\n\x16target_temperature_low\x18\x07 \x01(\x02\x12#\n\x1bhas_target_temperature_high\x18\x08 \x01(\x08\x12\x1f\n\x17target_temperature_high\x18\t \x01(\x02\x12\"\n\x16unused_has_legacy_away\x18\n \x01(\x08\x42\x02\x18\x01\x12\x1e\n\x12unused_legacy_away\x18\x0b \x01(\x08\x42\x02\x18\x01\x12\x14\n\x0chas_fan_mode\x18\x0c \x01(\x08\x12!\n\x08\x66\x61n_mode\x18\r \x01(\x0e\x32\x0f.ClimateFanMode\x12\x16\n\x0ehas_swing_mode\x18\x0e \x01(\x08\x12%\n\nswing_mode\x18\x0f \x01(\x0e\x32\x11.ClimateSwingMode\x12\x1b\n\x13has_custom_fan_mode\x18\x10 \x01(\x08\x12\x17\n\x0f\x63ustom_fan_mode\x18\x11 \x01(\t\x12\x12\n\nhas_preset\x18\x12 \x01(\x08\x12\x1e\n\x06preset\x18\x13 \x01(\x0e\x32\x0e.ClimatePreset\x12\x19\n\x11has_custom_preset\x18\x14 \x01(\x08\x12\x15\n\rcustom_preset\x18\x15 \x01(\t\x12\x1b\n\x13has_target_humidity\x18\x16 \x01(\x08\x12\x17\n\x0ftarget_humidity\x18\x17 \x01(\x02\x12!\n\tdevice_id\x18\x18 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:-\xe0@0\xe8@\x02\xf2@\x0bUSE_CLIMATE\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"\xd9\x03\n\x1fListEntitiesWaterHeaterResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x04 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x1b\n\x13\x64isabled_by_default\x18\x05 \x01(\x08\x12(\n\x0f\x65ntity_category\x18\x06 \x01(\x0e\x32\x0f.EntityCategory\x12!\n\tdevice_id\x18\x07 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES\x12\x17\n\x0fmin_temperature\x18\x08 \x01(\x02\x12\x17\n\x0fmax_temperature\x18\t \x01(\x02\x12\x1f\n\x17target_temperature_step\x18\n \x01(\x02\x12P\n\x0fsupported_modes\x18\x0b \x03(\x0e\x32\x10.WaterHeaterModeB%\xf2\xb5\x18!water_heater::WaterHeaterModeMask\x12\x1a\n\x12supported_features\x18\x0c \x01(\r:5\xe0@\x84\x01\xe8@\x01\xf2@\x10USE_WATER_HEATER\x8a\x41\x18InfoResponseProtoMessage\"\xb4\x02\n\x18WaterHeaterStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x1b\n\x13\x63urrent_temperature\x18\x02 \x01(\x02\x12\x1a\n\x12target_temperature\x18\x03 \x01(\x02\x12\x1e\n\x04mode\x18\x04 \x01(\x0e\x32\x10.WaterHeaterMode\x12!\n\tdevice_id\x18\x05 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES\x12\r\n\x05state\x18\x06 \x01(\r\x12\x1e\n\x16target_temperature_low\x18\x07 \x01(\x02\x12\x1f\n\x17target_temperature_high\x18\x08 \x01(\x02:9\xe0@\x85\x01\xe8@\x01\xf2@\x10USE_WATER_HEATER\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\xa6\x02\n\x19WaterHeaterCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x12\n\nhas_fields\x18\x02 \x01(\r\x12\x1e\n\x04mode\x18\x03 \x01(\x0e\x32\x10.WaterHeaterMode\x12\x1a\n\x12target_temperature\x18\x04 \x01(\x02\x12!\n\tdevice_id\x18\x05 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES\x12\r\n\x05state\x18\x06 \x01(\r\x12\x1e\n\x16target_temperature_low\x18\x07 \x01(\x02\x12\x1f\n\x17target_temperature_high\x18\x08 \x01(\x02:3\xe0@\x86\x01\xe8@\x02\xf2@\x10USE_WATER_HEATER\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"\x94\x03\n\x1aListEntitiesNumberResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x05 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x11\n\tmin_value\x18\x06 \x01(\x02\x12\x11\n\tmax_value\x18\x07 \x01(\x02\x12\x0c\n\x04step\x18\x08 \x01(\x02\x12\x1b\n\x13\x64isabled_by_default\x18\t \x01(\x08\x12(\n\x0f\x65ntity_category\x18\n \x01(\x0e\x32\x0f.EntityCategory\x12\x1b\n\x13unit_of_measurement\x18\x0b \x01(\t\x12\x19\n\x04mode\x18\x0c \x01(\x0e\x32\x0b.NumberMode\x12\x14\n\x0c\x64\x65vice_class\x18\r \x01(\t\x12!\n\tdevice_id\x18\x0e \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:.\xe0@1\xe8@\x01\xf2@\nUSE_NUMBER\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\xa5\x01\n\x13NumberStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\r\n\x05state\x18\x02 \x01(\x02\x12\x15\n\rmissing_state\x18\x03 \x01(\x08\x12!\n\tdevice_id\x18\x04 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:2\xe0@2\xe8@\x01\xf2@\nUSE_NUMBER\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\x89\x01\n\x14NumberCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\r\n\x05state\x18\x02 \x01(\x02\x12!\n\tdevice_id\x18\x03 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:,\xe0@3\xe8@\x02\xf2@\nUSE_NUMBER\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"\xc2\x02\n\x1aListEntitiesSelectResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x05 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12.\n\x07options\x18\x06 \x03(\tB\x1d\xf2\xb5\x18\x19\x46ixedVector<const char *>\x12\x1b\n\x13\x64isabled_by_default\x18\x07 \x01(\x08\x12(\n\x0f\x65ntity_category\x18\x08 \x01(\x0e\x32\x0f.EntityCategory\x12!\n\tdevice_id\x18\t \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:.\xe0@4\xe8@\x01\xf2@\nUSE_SELECT\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\xa5\x01\n\x13SelectStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\r\n\x05state\x18\x02 \x01(\t\x12\x15\n\rmissing_state\x18\x03 \x01(\x08\x12!\n\tdevice_id\x18\x04 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:2\xe0@5\xe8@\x01\xf2@\nUSE_SELECT\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\x89\x01\n\x14SelectCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\r\n\x05state\x18\x02 \x01(\t\x12!\n\tdevice_id\x18\x03 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:,\xe0@6\xe8@\x02\xf2@\nUSE_SELECT\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"\xf2\x02\n\x19ListEntitiesSirenResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x05 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x1b\n\x13\x64isabled_by_default\x18\x06 \x01(\x08\x12,\n\x05tones\x18\x07 \x03(\tB\x1d\xf2\xb5\x18\x19\x46ixedVector<const char *>\x12\x19\n\x11supports_duration\x18\x08 \x01(\x08\x12\x17\n\x0fsupports_volume\x18\t \x01(\x08\x12(\n\x0f\x65ntity_category\x18\n \x01(\x0e\x32\x0f.EntityCategory\x12!\n\tdevice_id\x18\x0b \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:-\xe0@7\xe8@\x01\xf2@\tUSE_SIREN\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\x8c\x01\n\x12SirenStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\r\n\x05state\x18\x02 \x01(\x08\x12!\n\tdevice_id\x18\x03 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:1\xe0@8\xe8@\x01\xf2@\tUSE_SIREN\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\x86\x02\n\x13SirenCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x11\n\thas_state\x18\x02 \x01(\x08\x12\r\n\x05state\x18\x03 \x01(\x08\x12\x10\n\x08has_tone\x18\x04 \x01(\x08\x12\x0c\n\x04tone\x18\x05 \x01(\t\x12\x14\n\x0chas_duration\x18\x06 \x01(\x08\x12\x10\n\x08\x64uration\x18\x07 \x01(\r\x12\x12\n\nhas_volume\x18\x08 \x01(\x08\x12\x0e\n\x06volume\x18\t \x01(\x02\x12!\n\tdevice_id\x18\n \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:+\xe0@9\xe8@\x02\xf2@\tUSE_SIREN\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"\xe8\x02\n\x18ListEntitiesLockResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x05 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x1b\n\x13\x64isabled_by_default\x18\x06 \x01(\x08\x12(\n\x0f\x65ntity_category\x18\x07 \x01(\x0e\x32\x0f.EntityCategory\x12\x15\n\rassumed_state\x18\x08 \x01(\x08\x12\x15\n\rsupports_open\x18\t \x01(\x08\x12\x15\n\rrequires_code\x18\n \x01(\x08\x12\x13\n\x0b\x63ode_format\x18\x0b \x01(\t\x12!\n\tdevice_id\x18\x0c \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:,\xe0@:\xe8@\x01\xf2@\x08USE_LOCK\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\x96\x01\n\x11LockStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x19\n\x05state\x18\x02 \x01(\x0e\x32\n.LockState\x12!\n\tdevice_id\x18\x03 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:0\xe0@;\xe8@\x01\xf2@\x08USE_LOCK\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\xb5\x01\n\x12LockCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x1d\n\x07\x63ommand\x18\x02 \x01(\x0e\x32\x0c.LockCommand\x12\x10\n\x08has_code\x18\x03 \x01(\x08\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12!\n\tdevice_id\x18\x05 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:*\xe0@<\xe8@\x02\xf2@\x08USE_LOCK\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"\xa8\x02\n\x1aListEntitiesButtonResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x05 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x1b\n\x13\x64isabled_by_default\x18\x06 \x01(\x08\x12(\n\x0f\x65ntity_category\x18\x07 \x01(\x0e\x32\x0f.EntityCategory\x12\x14\n\x0c\x64\x65vice_class\x18\x08 \x01(\t\x12!\n\tdevice_id\x18\t \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:.\xe0@=\xe8@\x01\xf2@\nUSE_BUTTON\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"z\n\x14\x42uttonCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12!\n\tdevice_id\x18\x02 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:,\xe0@>\xe8@\x02\xf2@\nUSE_BUTTON\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"\xae\x01\n\x1aMediaPlayerSupportedFormat\x12\x0e\n\x06\x66ormat\x18\x01 \x01(\t\x12\x13\n\x0bsample_rate\x18\x02 \x01(\r\x12\x14\n\x0cnum_channels\x18\x03 \x01(\r\x12*\n\x07purpose\x18\x04 \x01(\x0e\x32\x19.MediaPlayerFormatPurpose\x12\x14\n\x0csample_bytes\x18\x05 \x01(\r:\x13\xf2@\x10USE_MEDIA_PLAYER\"\x84\x03\n\x1fListEntitiesMediaPlayerResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x05 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x1b\n\x13\x64isabled_by_default\x18\x06 \x01(\x08\x12(\n\x0f\x65ntity_category\x18\x07 \x01(\x0e\x32\x0f.EntityCategory\x12\x16\n\x0esupports_pause\x18\x08 \x01(\x08\x12\x36\n\x11supported_formats\x18\t \x03(\x0b\x32\x1b.MediaPlayerSupportedFormat\x12!\n\tdevice_id\x18\n \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES\x12\x15\n\rfeature_flags\x18\x0b \x01(\r:4\xe0@?\xe8@\x01\xf2@\x10USE_MEDIA_PLAYER\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\xcb\x01\n\x18MediaPlayerStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12 \n\x05state\x18\x02 \x01(\x0e\x32\x11.MediaPlayerState\x12\x0e\n\x06volume\x18\x03 \x01(\x02\x12\r\n\x05muted\x18\x04 \x01(\x08\x12!\n\tdevice_id\x18\x05 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:8\xe0@@\xe8@\x01\xf2@\x10USE_MEDIA_PLAYER\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\xbe\x02\n\x19MediaPlayerCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x13\n\x0bhas_command\x18\x02 \x01(\x08\x12$\n\x07\x63ommand\x18\x03 \x01(\x0e\x32\x13.MediaPlayerCommand\x12\x12\n\nhas_volume\x18\x04 \x01(\x08\x12\x0e\n\x06volume\x18\x05 \x01(\x02\x12\x15\n\rhas_media_url\x18\x06 \x01(\x08\x12\x11\n\tmedia_url\x18\x07 \x01(\t\x12\x18\n\x10has_announcement\x18\x08 \x01(\x08\x12\x14\n\x0c\x61nnouncement\x18\t \x01(\x08\x12!\n\tdevice_id\x18\n \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:2\xe0@A\xe8@\x02\xf2@\x10USE_MEDIA_PLAYER\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"X\n)SubscribeBluetoothLEAdvertisementsRequest\x12\r\n\x05\x66lags\x18\x01 \x01(\r:\x1c\xe0@B\xe8@\x02\xf2@\x13USE_BLUETOOTH_PROXY\"O\n\x14\x42luetoothServiceData\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x17\n\x0blegacy_data\x18\x02 \x03(\rB\x02\x18\x01\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c:\x02\x18\x01\"\xfe\x01\n BluetoothLEAdvertisementResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\x0c\x12\x0c\n\x04rssi\x18\x03 \x01(\x11\x12\x15\n\rservice_uuids\x18\x04 \x03(\t\x12+\n\x0cservice_data\x18\x05 \x03(\x0b\x32\x15.BluetoothServiceData\x12\x30\n\x11manufacturer_data\x18\x06 \x03(\x0b\x32\x15.BluetoothServiceData\x12\x14\n\x0c\x61\x64\x64ress_type\x18\x07 \x01(\r:!\x18\x01\xe0@C\xe8@\x01\xf2@\x13USE_BLUETOOTH_PROXY\x80\x41\x01\"v\n\x1b\x42luetoothLERawAdvertisement\x12\x15\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x42\x04\x80\xb6\x18\x01\x12\x12\n\x04rssi\x18\x02 \x01(\x11\x42\x04\x80\xb6\x18\x01\x12\x14\n\x0c\x61\x64\x64ress_type\x18\x03 \x01(\r\x12\x16\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x42\x08\xb8\xb5\x18>\x80\xb6\x18\x01\"\xab\x01\n$BluetoothLERawAdvertisementsResponse\x12\x62\n\x0e\x61\x64vertisements\x18\x01 \x03(\x0b\x32\x1c.BluetoothLERawAdvertisementB,\xda\xb5\x18(BLUETOOTH_PROXY_ADVERTISEMENT_BATCH_SIZE:\x1f\xe0@]\xe8@\x01\xf2@\x13USE_BLUETOOTH_PROXY\x80\x41\x01\"\xaa\x01\n\x16\x42luetoothDeviceRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\x31\n\x0crequest_type\x18\x02 \x01(\x0e\x32\x1b.BluetoothDeviceRequestType\x12\x18\n\x10has_address_type\x18\x03 \x01(\x08\x12\x14\n\x0c\x61\x64\x64ress_type\x18\x04 \x01(\r:\x1c\xe0@D\xe8@\x02\xf2@\x13USE_BLUETOOTH_PROXY\"\x81\x01\n!BluetoothDeviceConnectionResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\x11\n\tconnected\x18\x02 \x01(\x08\x12\x0b\n\x03mtu\x18\x03 \x01(\r\x12\r\n\x05\x65rror\x18\x04 \x01(\x05:\x1c\xe0@E\xe8@\x01\xf2@\x13USE_BLUETOOTH_PROXY\"P\n\x1f\x42luetoothGATTGetServicesRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04:\x1c\xe0@F\xe8@\x02\xf2@\x13USE_BLUETOOTH_PROXY\"U\n\x17\x42luetoothGATTDescriptor\x12\x16\n\x04uuid\x18\x01 \x03(\x04\x42\x08\xb8\xb5\x18\x02\xc8\xb5\x18\x01\x12\x0e\n\x06handle\x18\x02 \x01(\r\x12\x12\n\nshort_uuid\x18\x03 \x01(\r\"\xa2\x01\n\x1b\x42luetoothGATTCharacteristic\x12\x16\n\x04uuid\x18\x01 \x03(\x04\x42\x08\xb8\xb5\x18\x02\xc8\xb5\x18\x01\x12\x0e\n\x06handle\x18\x02 \x01(\r\x12\x12\n\nproperties\x18\x03 \x01(\r\x12\x33\n\x0b\x64\x65scriptors\x18\x04 \x03(\x0b\x32\x18.BluetoothGATTDescriptorB\x04\xe8\xb5\x18\x01\x12\x12\n\nshort_uuid\x18\x05 \x01(\r\"\x8f\x01\n\x14\x42luetoothGATTService\x12\x16\n\x04uuid\x18\x01 \x03(\x04\x42\x08\xb8\xb5\x18\x02\xc8\xb5\x18\x01\x12\x0e\n\x06handle\x18\x02 \x01(\r\x12;\n\x0f\x63haracteristics\x18\x03 \x03(\x0b\x32\x1c.BluetoothGATTCharacteristicB\x04\xe8\xb5\x18\x01\x12\x12\n\nshort_uuid\x18\x04 \x01(\r\"z\n BluetoothGATTGetServicesResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\'\n\x08services\x18\x02 \x03(\x0b\x32\x15.BluetoothGATTService:\x1c\xe0@G\xe8@\x01\xf2@\x13USE_BLUETOOTH_PROXY\"U\n$BluetoothGATTGetServicesDoneResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04:\x1c\xe0@H\xe8@\x01\xf2@\x13USE_BLUETOOTH_PROXY\"Y\n\x18\x42luetoothGATTReadRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\x0e\n\x06handle\x18\x02 \x01(\r:\x1c\xe0@I\xe8@\x02\xf2@\x13USE_BLUETOOTH_PROXY\"h\n\x19\x42luetoothGATTReadResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\x0e\n\x06handle\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c:\x1c\xe0@J\xe8@\x01\xf2@\x13USE_BLUETOOTH_PROXY\"z\n\x19\x42luetoothGATTWriteRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\x0e\n\x06handle\x18\x02 \x01(\r\x12\x10\n\x08response\x18\x03 \x01(\x08\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c:\x1c\xe0@K\xe8@\x02\xf2@\x13USE_BLUETOOTH_PROXY\"c\n\"BluetoothGATTReadDescriptorRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\x0e\n\x06handle\x18\x02 \x01(\r:\x1c\xe0@L\xe8@\x02\xf2@\x13USE_BLUETOOTH_PROXY\"r\n#BluetoothGATTWriteDescriptorRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\x0e\n\x06handle\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c:\x1c\xe0@M\xe8@\x02\xf2@\x13USE_BLUETOOTH_PROXY\"k\n\x1a\x42luetoothGATTNotifyRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\x0e\n\x06handle\x18\x02 \x01(\r\x12\x0e\n\x06\x65nable\x18\x03 \x01(\x08:\x1c\xe0@N\xe8@\x02\xf2@\x13USE_BLUETOOTH_PROXY\"n\n\x1f\x42luetoothGATTNotifyDataResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\x0e\n\x06handle\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c:\x1c\xe0@O\xe8@\x01\xf2@\x13USE_BLUETOOTH_PROXY\"H\n(SubscribeBluetoothConnectionsFreeRequest:\x1c\xe0@P\xe8@\x02\xf2@\x13USE_BLUETOOTH_PROXY\"\x99\x01\n BluetoothConnectionsFreeResponse\x12\x0c\n\x04\x66ree\x18\x01 \x01(\r\x12\r\n\x05limit\x18\x02 \x01(\r\x12:\n\tallocated\x18\x03 \x03(\x04\x42\'\xc8\xb5\x18\x01\xd2\xb5\x18\x1f\x42LUETOOTH_PROXY_MAX_CONNECTIONS:\x1c\xe0@Q\xe8@\x01\xf2@\x13USE_BLUETOOTH_PROXY\"j\n\x1a\x42luetoothGATTErrorResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\x0e\n\x06handle\x18\x02 \x01(\r\x12\r\n\x05\x65rror\x18\x03 \x01(\x05:\x1c\xe0@R\xe8@\x01\xf2@\x13USE_BLUETOOTH_PROXY\"[\n\x1a\x42luetoothGATTWriteResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\x0e\n\x06handle\x18\x02 \x01(\r:\x1c\xe0@S\xe8@\x01\xf2@\x13USE_BLUETOOTH_PROXY\"\\\n\x1b\x42luetoothGATTNotifyResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\x0e\n\x06handle\x18\x02 \x01(\r:\x1c\xe0@T\xe8@\x01\xf2@\x13USE_BLUETOOTH_PROXY\"n\n\x1e\x42luetoothDevicePairingResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\x0e\n\x06paired\x18\x02 \x01(\x08\x12\r\n\x05\x65rror\x18\x03 \x01(\x05:\x1c\xe0@U\xe8@\x01\xf2@\x13USE_BLUETOOTH_PROXY\"q\n BluetoothDeviceUnpairingResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\r\n\x05\x65rror\x18\x03 \x01(\x05:\x1c\xe0@V\xe8@\x01\xf2@\x13USE_BLUETOOTH_PROXY\"K\n+UnsubscribeBluetoothLEAdvertisementsRequest:\x1c\xe0@W\xe8@\x02\xf2@\x13USE_BLUETOOTH_PROXY\"r\n!BluetoothDeviceClearCacheResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\r\n\x05\x65rror\x18\x03 \x01(\x05:\x1c\xe0@X\xe8@\x01\xf2@\x13USE_BLUETOOTH_PROXY\"\xb9\x01\n\x1d\x42luetoothScannerStateResponse\x12%\n\x05state\x18\x01 \x01(\x0e\x32\x16.BluetoothScannerState\x12#\n\x04mode\x18\x02 \x01(\x0e\x32\x15.BluetoothScannerMode\x12.\n\x0f\x63onfigured_mode\x18\x03 \x01(\x0e\x32\x15.BluetoothScannerMode:\x1c\xe0@~\xe8@\x01\xf2@\x13USE_BLUETOOTH_PROXY\"c\n\x1e\x42luetoothScannerSetModeRequest\x12#\n\x04mode\x18\x01 \x01(\x0e\x32\x15.BluetoothScannerMode:\x1c\xe0@\x7f\xe8@\x02\xf2@\x13USE_BLUETOOTH_PROXY\"`\n\x1eSubscribeVoiceAssistantRequest\x12\x11\n\tsubscribe\x18\x01 \x01(\x08\x12\r\n\x05\x66lags\x18\x02 \x01(\r:\x1c\xe0@Y\xe8@\x02\xf2@\x13USE_VOICE_ASSISTANT\"l\n\x1bVoiceAssistantAudioSettings\x12\x1f\n\x17noise_suppression_level\x18\x01 \x01(\r\x12\x11\n\tauto_gain\x18\x02 \x01(\r\x12\x19\n\x11volume_multiplier\x18\x03 \x01(\x02\"\xbc\x01\n\x15VoiceAssistantRequest\x12\r\n\x05start\x18\x01 \x01(\x08\x12\x17\n\x0f\x63onversation_id\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\r\x12\x34\n\x0e\x61udio_settings\x18\x04 \x01(\x0b\x32\x1c.VoiceAssistantAudioSettings\x12\x18\n\x10wake_word_phrase\x18\x05 \x01(\t:\x1c\xe0@Z\xe8@\x01\xf2@\x13USE_VOICE_ASSISTANT\"S\n\x16VoiceAssistantResponse\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\r\n\x05\x65rror\x18\x02 \x01(\x08:\x1c\xe0@[\xe8@\x02\xf2@\x13USE_VOICE_ASSISTANT\"6\n\x17VoiceAssistantEventData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x8d\x01\n\x1bVoiceAssistantEventResponse\x12(\n\nevent_type\x18\x01 \x01(\x0e\x32\x14.VoiceAssistantEvent\x12&\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x18.VoiceAssistantEventData:\x1c\xe0@\\\xe8@\x02\xf2@\x13USE_VOICE_ASSISTANT\"T\n\x13VoiceAssistantAudio\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42\x04\xe0\xb5\x18\x01\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x08:\x1c\xe0@j\xe8@\x00\xf2@\x13USE_VOICE_ASSISTANT\"\xcf\x01\n VoiceAssistantTimerEventResponse\x12-\n\nevent_type\x18\x01 \x01(\x0e\x32\x19.VoiceAssistantTimerEvent\x12\x10\n\x08timer_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x15\n\rtotal_seconds\x18\x04 \x01(\r\x12\x14\n\x0cseconds_left\x18\x05 \x01(\r\x12\x11\n\tis_active\x18\x06 \x01(\x08:\x1c\xe0@s\xe8@\x02\xf2@\x13USE_VOICE_ASSISTANT\"\x97\x01\n\x1dVoiceAssistantAnnounceRequest\x12\x10\n\x08media_id\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x1c\n\x14preannounce_media_id\x18\x03 \x01(\t\x12\x1a\n\x12start_conversation\x18\x04 \x01(\x08:\x1c\xe0@w\xe8@\x02\xf2@\x13USE_VOICE_ASSISTANT\"O\n\x1eVoiceAssistantAnnounceFinished\x12\x0f\n\x07success\x18\x01 \x01(\x08:\x1c\xe0@x\xe8@\x01\xf2@\x13USE_VOICE_ASSISTANT\"R\n\x16VoiceAssistantWakeWord\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\twake_word\x18\x02 \x01(\t\x12\x19\n\x11trained_languages\x18\x03 \x03(\t\"\xa3\x01\n\x1eVoiceAssistantExternalWakeWord\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\twake_word\x18\x02 \x01(\t\x12\x19\n\x11trained_languages\x18\x03 \x03(\t\x12\x12\n\nmodel_type\x18\x04 \x01(\t\x12\x12\n\nmodel_size\x18\x05 \x01(\r\x12\x12\n\nmodel_hash\x18\x06 \x01(\t\x12\x0b\n\x03url\x18\x07 \x01(\t\"\x80\x01\n\"VoiceAssistantConfigurationRequest\x12<\n\x13\x65xternal_wake_words\x18\x01 \x03(\x0b\x32\x1f.VoiceAssistantExternalWakeWord:\x1c\xe0@y\xe8@\x02\xf2@\x13USE_VOICE_ASSISTANT\"\xc5\x01\n#VoiceAssistantConfigurationResponse\x12\x35\n\x14\x61vailable_wake_words\x18\x01 \x03(\x0b\x32\x17.VoiceAssistantWakeWord\x12*\n\x11\x61\x63tive_wake_words\x18\x02 \x03(\tB\x0f\x8a\xb5\x18\x0bstd::vector\x12\x1d\n\x15max_active_wake_words\x18\x03 \x01(\r:\x1c\xe0@z\xe8@\x01\xf2@\x13USE_VOICE_ASSISTANT\"Y\n\x1eVoiceAssistantSetConfiguration\x12\x19\n\x11\x61\x63tive_wake_words\x18\x01 \x03(\t:\x1c\xe0@{\xe8@\x02\xf2@\x13USE_VOICE_ASSISTANT\"\xfb\x02\n%ListEntitiesAlarmControlPanelResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x05 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x1b\n\x13\x64isabled_by_default\x18\x06 \x01(\x08\x12(\n\x0f\x65ntity_category\x18\x07 \x01(\x0e\x32\x0f.EntityCategory\x12\x1a\n\x12supported_features\x18\x08 \x01(\r\x12\x15\n\rrequires_code\x18\t \x01(\x08\x12\x1c\n\x14requires_code_to_arm\x18\n \x01(\x08\x12!\n\tdevice_id\x18\x0b \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:;\xe0@^\xe8@\x01\xf2@\x17USE_ALARM_CONTROL_PANEL\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\xbf\x01\n\x1e\x41larmControlPanelStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12&\n\x05state\x18\x02 \x01(\x0e\x32\x17.AlarmControlPanelState\x12!\n\tdevice_id\x18\x03 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:?\xe0@_\xe8@\x01\xf2@\x17USE_ALARM_CONTROL_PANEL\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\xd1\x01\n\x1f\x41larmControlPanelCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12/\n\x07\x63ommand\x18\x02 \x01(\x0e\x32\x1e.AlarmControlPanelStateCommand\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12!\n\tdevice_id\x18\x04 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:9\xe0@`\xe8@\x02\xf2@\x17USE_ALARM_CONTROL_PANEL\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"\xe0\x02\n\x18ListEntitiesTextResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x05 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x1b\n\x13\x64isabled_by_default\x18\x06 \x01(\x08\x12(\n\x0f\x65ntity_category\x18\x07 \x01(\x0e\x32\x0f.EntityCategory\x12\x12\n\nmin_length\x18\x08 \x01(\r\x12\x12\n\nmax_length\x18\t \x01(\r\x12\x0f\n\x07pattern\x18\n \x01(\t\x12\x17\n\x04mode\x18\x0b \x01(\x0e\x32\t.TextMode\x12!\n\tdevice_id\x18\x0c \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:,\xe0@a\xe8@\x01\xf2@\x08USE_TEXT\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\xa1\x01\n\x11TextStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\r\n\x05state\x18\x02 \x01(\t\x12\x15\n\rmissing_state\x18\x03 \x01(\x08\x12!\n\tdevice_id\x18\x04 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:0\xe0@b\xe8@\x01\xf2@\x08USE_TEXT\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\x85\x01\n\x12TextCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\r\n\x05state\x18\x02 \x01(\t\x12!\n\tdevice_id\x18\x03 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:*\xe0@c\xe8@\x02\xf2@\x08USE_TEXT\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"\x97\x02\n\x18ListEntitiesDateResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x05 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x1b\n\x13\x64isabled_by_default\x18\x06 \x01(\x08\x12(\n\x0f\x65ntity_category\x18\x07 \x01(\x0e\x32\x0f.EntityCategory\x12!\n\tdevice_id\x18\x08 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:5\xe0@d\xe8@\x01\xf2@\x11USE_DATETIME_DATE\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\xc5\x01\n\x11\x44\x61teStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x15\n\rmissing_state\x18\x02 \x01(\x08\x12\x0c\n\x04year\x18\x03 \x01(\r\x12\r\n\x05month\x18\x04 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x05 \x01(\r\x12!\n\tdevice_id\x18\x06 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:9\xe0@e\xe8@\x01\xf2@\x11USE_DATETIME_DATE\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\xa9\x01\n\x12\x44\x61teCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04year\x18\x02 \x01(\r\x12\r\n\x05month\x18\x03 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x04 \x01(\r\x12!\n\tdevice_id\x18\x05 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:3\xe0@f\xe8@\x02\xf2@\x11USE_DATETIME_DATE\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"\x97\x02\n\x18ListEntitiesTimeResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x05 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x1b\n\x13\x64isabled_by_default\x18\x06 \x01(\x08\x12(\n\x0f\x65ntity_category\x18\x07 \x01(\x0e\x32\x0f.EntityCategory\x12!\n\tdevice_id\x18\x08 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:5\xe0@g\xe8@\x01\xf2@\x11USE_DATETIME_TIME\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\xc9\x01\n\x11TimeStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x15\n\rmissing_state\x18\x02 \x01(\x08\x12\x0c\n\x04hour\x18\x03 \x01(\r\x12\x0e\n\x06minute\x18\x04 \x01(\r\x12\x0e\n\x06second\x18\x05 \x01(\r\x12!\n\tdevice_id\x18\x06 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:9\xe0@h\xe8@\x01\xf2@\x11USE_DATETIME_TIME\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\xad\x01\n\x12TimeCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04hour\x18\x02 \x01(\r\x12\x0e\n\x06minute\x18\x03 \x01(\r\x12\x0e\n\x06second\x18\x04 \x01(\r\x12!\n\tdevice_id\x18\x05 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:3\xe0@i\xe8@\x02\xf2@\x11USE_DATETIME_TIME\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"\xda\x02\n\x19ListEntitiesEventResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x05 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x1b\n\x13\x64isabled_by_default\x18\x06 \x01(\x08\x12(\n\x0f\x65ntity_category\x18\x07 \x01(\x0e\x32\x0f.EntityCategory\x12\x14\n\x0c\x64\x65vice_class\x18\x08 \x01(\t\x12\x32\n\x0b\x65vent_types\x18\t \x03(\tB\x1d\xf2\xb5\x18\x19\x46ixedVector<const char *>\x12!\n\tdevice_id\x18\n \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:-\xe0@k\xe8@\x01\xf2@\tUSE_EVENT\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\x89\x01\n\rEventResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x12\n\nevent_type\x18\x02 \x01(\t\x12!\n\tdevice_id\x18\x03 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:.\xe0@l\xe8@\x01\xf2@\tUSE_EVENT\x8a\x41\x19StateResponseProtoMessage\"\xef\x02\n\x19ListEntitiesValveResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x05 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x1b\n\x13\x64isabled_by_default\x18\x06 \x01(\x08\x12(\n\x0f\x65ntity_category\x18\x07 \x01(\x0e\x32\x0f.EntityCategory\x12\x14\n\x0c\x64\x65vice_class\x18\x08 \x01(\t\x12\x15\n\rassumed_state\x18\t \x01(\x08\x12\x19\n\x11supports_position\x18\n \x01(\x08\x12\x15\n\rsupports_stop\x18\x0b \x01(\x08\x12!\n\tdevice_id\x18\x0c \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:-\xe0@m\xe8@\x01\xf2@\tUSE_VALVE\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\xbb\x01\n\x12ValveStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x10\n\x08position\x18\x02 \x01(\x02\x12*\n\x11\x63urrent_operation\x18\x03 \x01(\x0e\x32\x0f.ValveOperation\x12!\n\tdevice_id\x18\x04 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:1\xe0@n\xe8@\x01\xf2@\tUSE_VALVE\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\xae\x01\n\x13ValveCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x14\n\x0chas_position\x18\x02 \x01(\x08\x12\x10\n\x08position\x18\x03 \x01(\x02\x12\x0c\n\x04stop\x18\x04 \x01(\x08\x12!\n\tdevice_id\x18\x05 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:+\xe0@o\xe8@\x02\xf2@\tUSE_VALVE\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"\x9f\x02\n\x1cListEntitiesDateTimeResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x05 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x1b\n\x13\x64isabled_by_default\x18\x06 \x01(\x08\x12(\n\x0f\x65ntity_category\x18\x07 \x01(\x0e\x32\x0f.EntityCategory\x12!\n\tdevice_id\x18\x08 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:9\xe0@p\xe8@\x01\xf2@\x15USE_DATETIME_DATETIME\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\xba\x01\n\x15\x44\x61teTimeStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x15\n\rmissing_state\x18\x02 \x01(\x08\x12\x15\n\repoch_seconds\x18\x03 \x01(\x07\x12!\n\tdevice_id\x18\x04 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:=\xe0@q\xe8@\x01\xf2@\x15USE_DATETIME_DATETIME\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\x9e\x01\n\x16\x44\x61teTimeCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x15\n\repoch_seconds\x18\x02 \x01(\x07\x12!\n\tdevice_id\x18\x03 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:7\xe0@r\xe8@\x02\xf2@\x15USE_DATETIME_DATETIME\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"\xa8\x02\n\x1aListEntitiesUpdateResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x05 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x1b\n\x13\x64isabled_by_default\x18\x06 \x01(\x08\x12(\n\x0f\x65ntity_category\x18\x07 \x01(\x0e\x32\x0f.EntityCategory\x12\x14\n\x0c\x64\x65vice_class\x18\x08 \x01(\t\x12!\n\tdevice_id\x18\t \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:.\xe0@t\xe8@\x01\xf2@\nUSE_UPDATE\x8a\x41\x18InfoResponseProtoMessageJ\x04\x08\x04\x10\x05\"\xc1\x02\n\x13UpdateStateResponse\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x15\n\rmissing_state\x18\x02 \x01(\x08\x12\x13\n\x0bin_progress\x18\x03 \x01(\x08\x12\x14\n\x0chas_progress\x18\x04 \x01(\x08\x12\x10\n\x08progress\x18\x05 \x01(\x02\x12\x17\n\x0f\x63urrent_version\x18\x06 \x01(\t\x12\x16\n\x0elatest_version\x18\x07 \x01(\t\x12\r\n\x05title\x18\x08 \x01(\t\x12\x17\n\x0frelease_summary\x18\t \x01(\t\x12\x13\n\x0brelease_url\x18\n \x01(\t\x12!\n\tdevice_id\x18\x0b \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:2\xe0@u\xe8@\x01\xf2@\nUSE_UPDATE\x80\x41\x01\x8a\x41\x19StateResponseProtoMessage\"\x9b\x01\n\x14UpdateCommandRequest\x12\x11\n\x03key\x18\x01 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x1f\n\x07\x63ommand\x18\x02 \x01(\x0e\x32\x0e.UpdateCommand\x12!\n\tdevice_id\x18\x03 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES:,\xe0@v\xe8@\x02\xf2@\nUSE_UPDATE\x80\x41\x01\x8a\x41\x13\x43ommandProtoMessage\"=\n\x0fZWaveProxyFrame\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c:\x1c\xe0@\x80\x01\xe8@\x00\xf2@\x0fUSE_ZWAVE_PROXY\x80\x41\x01\"b\n\x11ZWaveProxyRequest\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.ZWaveProxyRequestType\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c:\x19\xe0@\x81\x01\xe8@\x00\xf2@\x0fUSE_ZWAVE_PROXY\"\xa7\x02\n\x1cListEntitiesInfraredResponse\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04icon\x18\x04 \x01(\tB\x12\x92\x41\x0fUSE_ENTITY_ICON\x12\x1b\n\x13\x64isabled_by_default\x18\x05 \x01(\x08\x12(\n\x0f\x65ntity_category\x18\x06 \x01(\x0e\x32\x0f.EntityCategory\x12!\n\tdevice_id\x18\x07 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES\x12\x14\n\x0c\x63\x61pabilities\x18\x08 \x01(\r:1\xe0@\x87\x01\xe8@\x01\xf2@\x0cUSE_INFRARED\x8a\x41\x18InfoResponseProtoMessage\"\xba\x01\n#InfraredRFTransmitRawTimingsRequest\x12!\n\tdevice_id\x18\x01 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12\x19\n\x11\x63\x61rrier_frequency\x18\x03 \x01(\r\x12\x14\n\x0crepeat_count\x18\x04 \x01(\r\x12\x17\n\x07timings\x18\x05 \x03(\x11\x42\x06\x10\x01\xf8\xb5\x18\x01:\x13\xe0@\x88\x01\xe8@\x02\xf2@\tUSE_IR_RF\"\x93\x01\n\x16InfraredRFReceiveEvent\x12!\n\tdevice_id\x18\x01 \x01(\rB\x0e\x92\x41\x0bUSE_DEVICES\x12\x11\n\x03key\x18\x02 \x01(\x07\x42\x04\x80\xb6\x18\x01\x12+\n\x07timings\x18\x03 \x03(\x11\x42\x1a\x10\x01\xf2\xb5\x18\x14std::vector<int32_t>:\x16\xe0@\x89\x01\xe8@\x01\xf2@\tUSE_IR_RF\x80\x41\x01\"\xbd\x01\n\x1bSerialProxyConfigureRequest\x12\x10\n\x08instance\x18\x01 \x01(\r\x12\x10\n\x08\x62\x61udrate\x18\x02 \x01(\r\x12\x14\n\x0c\x66low_control\x18\x03 \x01(\x08\x12\"\n\x06parity\x18\x04 \x01(\x0e\x32\x12.SerialProxyParity\x12\x11\n\tstop_bits\x18\x05 \x01(\r\x12\x11\n\tdata_size\x18\x06 \x01(\r:\x1a\xe0@\x8a\x01\xe8@\x02\xf2@\x10USE_SERIAL_PROXY\"X\n\x17SerialProxyDataReceived\x12\x10\n\x08instance\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c:\x1d\xe0@\x8b\x01\xe8@\x01\xf2@\x10USE_SERIAL_PROXY\x80\x41\x01\"X\n\x17SerialProxyWriteRequest\x12\x10\n\x08instance\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c:\x1d\xe0@\x8c\x01\xe8@\x02\xf2@\x10USE_SERIAL_PROXY\x80\x41\x01\"c\n\x1eSerialProxySetModemPinsRequest\x12\x10\n\x08instance\x18\x01 \x01(\r\x12\x13\n\x0bline_states\x18\x02 \x01(\r:\x1a\xe0@\x8d\x01\xe8@\x02\xf2@\x10USE_SERIAL_PROXY\"N\n\x1eSerialProxyGetModemPinsRequest\x12\x10\n\x08instance\x18\x01 \x01(\r:\x1a\xe0@\x8e\x01\xe8@\x02\xf2@\x10USE_SERIAL_PROXY\"d\n\x1fSerialProxyGetModemPinsResponse\x12\x10\n\x08instance\x18\x01 \x01(\r\x12\x13\n\x0bline_states\x18\x02 \x01(\r:\x1a\xe0@\x8f\x01\xe8@\x01\xf2@\x10USE_SERIAL_PROXY\"i\n\x12SerialProxyRequest\x12\x10\n\x08instance\x18\x01 \x01(\r\x12%\n\x04type\x18\x02 \x01(\x0e\x32\x17.SerialProxyRequestType:\x1a\xe0@\x90\x01\xe8@\x02\xf2@\x10USE_SERIAL_PROXY\"\xac\x01\n\x1aSerialProxyRequestResponse\x12\x10\n\x08instance\x18\x01 \x01(\r\x12%\n\x04type\x18\x02 \x01(\x0e\x32\x17.SerialProxyRequestType\x12\"\n\x06status\x18\x03 \x01(\x0e\x32\x12.SerialProxyStatus\x12\x15\n\rerror_message\x18\x04 \x01(\t:\x1a\xe0@\x93\x01\xe8@\x01\xf2@\x10USE_SERIAL_PROXY\"\xa3\x01\n#BluetoothSetConnectionParamsRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\x14\n\x0cmin_interval\x18\x02 \x01(\r\x12\x14\n\x0cmax_interval\x18\x03 \x01(\r\x12\x0f\n\x07latency\x18\x04 \x01(\r\x12\x0f\n\x07timeout\x18\x05 \x01(\r:\x1d\xe0@\x91\x01\xe8@\x02\xf2@\x13USE_BLUETOOTH_PROXY\"e\n$BluetoothSetConnectionParamsResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12\r\n\x05\x65rror\x18\x02 \x01(\x05:\x1d\xe0@\x92\x01\xe8@\x01\xf2@\x13USE_BLUETOOTH_PROXY*y\n\x13SerialProxyPortType\x12\x1e\n\x1aSERIAL_PROXY_PORT_TYPE_TTL\x10\x00\x12 \n\x1cSERIAL_PROXY_PORT_TYPE_RS232\x10\x01\x12 \n\x1cSERIAL_PROXY_PORT_TYPE_RS485\x10\x02*f\n\x0e\x45ntityCategory\x12\x18\n\x14\x45NTITY_CATEGORY_NONE\x10\x00\x12\x1a\n\x16\x45NTITY_CATEGORY_CONFIG\x10\x01\x12\x1e\n\x1a\x45NTITY_CATEGORY_DIAGNOSTIC\x10\x02*R\n\x10LegacyCoverState\x12\x1b\n\x17LEGACY_COVER_STATE_OPEN\x10\x00\x12\x1d\n\x19LEGACY_COVER_STATE_CLOSED\x10\x01\x1a\x02\x18\x01*j\n\x0e\x43overOperation\x12\x18\n\x14\x43OVER_OPERATION_IDLE\x10\x00\x12\x1e\n\x1a\x43OVER_OPERATION_IS_OPENING\x10\x01\x12\x1e\n\x1a\x43OVER_OPERATION_IS_CLOSING\x10\x02*v\n\x12LegacyCoverCommand\x12\x1d\n\x19LEGACY_COVER_COMMAND_OPEN\x10\x00\x12\x1e\n\x1aLEGACY_COVER_COMMAND_CLOSE\x10\x01\x12\x1d\n\x19LEGACY_COVER_COMMAND_STOP\x10\x02\x1a\x02\x18\x01*K\n\x08\x46\x61nSpeed\x12\x11\n\rFAN_SPEED_LOW\x10\x00\x12\x14\n\x10\x46\x41N_SPEED_MEDIUM\x10\x01\x12\x12\n\x0e\x46\x41N_SPEED_HIGH\x10\x02\x1a\x02\x18\x01*D\n\x0c\x46\x61nDirection\x12\x19\n\x15\x46\x41N_DIRECTION_FORWARD\x10\x00\x12\x19\n\x15\x46\x41N_DIRECTION_REVERSE\x10\x01*\xc7\x02\n\tColorMode\x12\x16\n\x12\x43OLOR_MODE_UNKNOWN\x10\x00\x12\x15\n\x11\x43OLOR_MODE_ON_OFF\x10\x01\x12 \n\x1c\x43OLOR_MODE_LEGACY_BRIGHTNESS\x10\x02\x12\x19\n\x15\x43OLOR_MODE_BRIGHTNESS\x10\x03\x12\x14\n\x10\x43OLOR_MODE_WHITE\x10\x07\x12 \n\x1c\x43OLOR_MODE_COLOR_TEMPERATURE\x10\x0b\x12\x1e\n\x1a\x43OLOR_MODE_COLD_WARM_WHITE\x10\x13\x12\x12\n\x0e\x43OLOR_MODE_RGB\x10#\x12\x18\n\x14\x43OLOR_MODE_RGB_WHITE\x10\'\x12$\n COLOR_MODE_RGB_COLOR_TEMPERATURE\x10/\x12\"\n\x1e\x43OLOR_MODE_RGB_COLD_WARM_WHITE\x10\x33*\xa1\x01\n\x10SensorStateClass\x12\x14\n\x10STATE_CLASS_NONE\x10\x00\x12\x1b\n\x17STATE_CLASS_MEASUREMENT\x10\x01\x12 \n\x1cSTATE_CLASS_TOTAL_INCREASING\x10\x02\x12\x15\n\x11STATE_CLASS_TOTAL\x10\x03\x12!\n\x1dSTATE_CLASS_MEASUREMENT_ANGLE\x10\x04*Y\n\x13SensorLastResetType\x12\x13\n\x0fLAST_RESET_NONE\x10\x00\x12\x14\n\x10LAST_RESET_NEVER\x10\x01\x12\x13\n\x0fLAST_RESET_AUTO\x10\x02\x1a\x02\x18\x01*\xb9\x01\n\x08LogLevel\x12\x12\n\x0eLOG_LEVEL_NONE\x10\x00\x12\x13\n\x0fLOG_LEVEL_ERROR\x10\x01\x12\x12\n\x0eLOG_LEVEL_WARN\x10\x02\x12\x12\n\x0eLOG_LEVEL_INFO\x10\x03\x12\x14\n\x10LOG_LEVEL_CONFIG\x10\x04\x12\x13\n\x0fLOG_LEVEL_DEBUG\x10\x05\x12\x15\n\x11LOG_LEVEL_VERBOSE\x10\x06\x12\x1a\n\x16LOG_LEVEL_VERY_VERBOSE\x10\x07*\x88\x01\n\x0b\x44STRuleType\x12\x16\n\x12\x44ST_RULE_TYPE_NONE\x10\x00\x12 \n\x1c\x44ST_RULE_TYPE_MONTH_WEEK_DAY\x10\x01\x12 \n\x1c\x44ST_RULE_TYPE_JULIAN_NO_LEAP\x10\x02\x12\x1d\n\x19\x44ST_RULE_TYPE_DAY_OF_YEAR\x10\x03*\x84\x02\n\x0eServiceArgType\x12\x19\n\x15SERVICE_ARG_TYPE_BOOL\x10\x00\x12\x18\n\x14SERVICE_ARG_TYPE_INT\x10\x01\x12\x1a\n\x16SERVICE_ARG_TYPE_FLOAT\x10\x02\x12\x1b\n\x17SERVICE_ARG_TYPE_STRING\x10\x03\x12\x1f\n\x1bSERVICE_ARG_TYPE_BOOL_ARRAY\x10\x04\x12\x1e\n\x1aSERVICE_ARG_TYPE_INT_ARRAY\x10\x05\x12 \n\x1cSERVICE_ARG_TYPE_FLOAT_ARRAY\x10\x06\x12!\n\x1dSERVICE_ARG_TYPE_STRING_ARRAY\x10\x07*\x8c\x01\n\x14SupportsResponseType\x12\x1a\n\x16SUPPORTS_RESPONSE_NONE\x10\x00\x12\x1e\n\x1aSUPPORTS_RESPONSE_OPTIONAL\x10\x01\x12\x1a\n\x16SUPPORTS_RESPONSE_ONLY\x10\x02\x12\x1c\n\x18SUPPORTS_RESPONSE_STATUS\x10\x64*\xb5\x01\n\x0b\x43limateMode\x12\x14\n\x10\x43LIMATE_MODE_OFF\x10\x00\x12\x1a\n\x16\x43LIMATE_MODE_HEAT_COOL\x10\x01\x12\x15\n\x11\x43LIMATE_MODE_COOL\x10\x02\x12\x15\n\x11\x43LIMATE_MODE_HEAT\x10\x03\x12\x19\n\x15\x43LIMATE_MODE_FAN_ONLY\x10\x04\x12\x14\n\x10\x43LIMATE_MODE_DRY\x10\x05\x12\x15\n\x11\x43LIMATE_MODE_AUTO\x10\x06*\xf1\x01\n\x0e\x43limateFanMode\x12\x12\n\x0e\x43LIMATE_FAN_ON\x10\x00\x12\x13\n\x0f\x43LIMATE_FAN_OFF\x10\x01\x12\x14\n\x10\x43LIMATE_FAN_AUTO\x10\x02\x12\x13\n\x0f\x43LIMATE_FAN_LOW\x10\x03\x12\x16\n\x12\x43LIMATE_FAN_MEDIUM\x10\x04\x12\x14\n\x10\x43LIMATE_FAN_HIGH\x10\x05\x12\x16\n\x12\x43LIMATE_FAN_MIDDLE\x10\x06\x12\x15\n\x11\x43LIMATE_FAN_FOCUS\x10\x07\x12\x17\n\x13\x43LIMATE_FAN_DIFFUSE\x10\x08\x12\x15\n\x11\x43LIMATE_FAN_QUIET\x10\t*{\n\x10\x43limateSwingMode\x12\x15\n\x11\x43LIMATE_SWING_OFF\x10\x00\x12\x16\n\x12\x43LIMATE_SWING_BOTH\x10\x01\x12\x1a\n\x16\x43LIMATE_SWING_VERTICAL\x10\x02\x12\x1c\n\x18\x43LIMATE_SWING_HORIZONTAL\x10\x03*\xca\x01\n\rClimateAction\x12\x16\n\x12\x43LIMATE_ACTION_OFF\x10\x00\x12\x1a\n\x16\x43LIMATE_ACTION_COOLING\x10\x02\x12\x1a\n\x16\x43LIMATE_ACTION_HEATING\x10\x03\x12\x17\n\x13\x43LIMATE_ACTION_IDLE\x10\x04\x12\x19\n\x15\x43LIMATE_ACTION_DRYING\x10\x05\x12\x16\n\x12\x43LIMATE_ACTION_FAN\x10\x06\x12\x1d\n\x19\x43LIMATE_ACTION_DEFROSTING\x10\x07*\xdf\x01\n\rClimatePreset\x12\x17\n\x13\x43LIMATE_PRESET_NONE\x10\x00\x12\x17\n\x13\x43LIMATE_PRESET_HOME\x10\x01\x12\x17\n\x13\x43LIMATE_PRESET_AWAY\x10\x02\x12\x18\n\x14\x43LIMATE_PRESET_BOOST\x10\x03\x12\x1a\n\x16\x43LIMATE_PRESET_COMFORT\x10\x04\x12\x16\n\x12\x43LIMATE_PRESET_ECO\x10\x05\x12\x18\n\x14\x43LIMATE_PRESET_SLEEP\x10\x06\x12\x1b\n\x17\x43LIMATE_PRESET_ACTIVITY\x10\x07*\xe9\x01\n\x0fWaterHeaterMode\x12\x19\n\x15WATER_HEATER_MODE_OFF\x10\x00\x12\x19\n\x15WATER_HEATER_MODE_ECO\x10\x01\x12\x1e\n\x1aWATER_HEATER_MODE_ELECTRIC\x10\x02\x12!\n\x1dWATER_HEATER_MODE_PERFORMANCE\x10\x03\x12!\n\x1dWATER_HEATER_MODE_HIGH_DEMAND\x10\x04\x12\x1f\n\x1bWATER_HEATER_MODE_HEAT_PUMP\x10\x05\x12\x19\n\x15WATER_HEATER_MODE_GAS\x10\x06*\xf6\x02\n\x1aWaterHeaterCommandHasField\x12!\n\x1dWATER_HEATER_COMMAND_HAS_NONE\x10\x00\x12!\n\x1dWATER_HEATER_COMMAND_HAS_MODE\x10\x01\x12/\n+WATER_HEATER_COMMAND_HAS_TARGET_TEMPERATURE\x10\x02\x12&\n\x1eWATER_HEATER_COMMAND_HAS_STATE\x10\x04\x1a\x02\x08\x01\x12\x33\n/WATER_HEATER_COMMAND_HAS_TARGET_TEMPERATURE_LOW\x10\x08\x12\x34\n0WATER_HEATER_COMMAND_HAS_TARGET_TEMPERATURE_HIGH\x10\x10\x12%\n!WATER_HEATER_COMMAND_HAS_ON_STATE\x10 \x12\'\n#WATER_HEATER_COMMAND_HAS_AWAY_STATE\x10@*O\n\nNumberMode\x12\x14\n\x10NUMBER_MODE_AUTO\x10\x00\x12\x13\n\x0fNUMBER_MODE_BOX\x10\x01\x12\x16\n\x12NUMBER_MODE_SLIDER\x10\x02*\x99\x01\n\tLockState\x12\x13\n\x0fLOCK_STATE_NONE\x10\x00\x12\x15\n\x11LOCK_STATE_LOCKED\x10\x01\x12\x17\n\x13LOCK_STATE_UNLOCKED\x10\x02\x12\x15\n\x11LOCK_STATE_JAMMED\x10\x03\x12\x16\n\x12LOCK_STATE_LOCKING\x10\x04\x12\x18\n\x14LOCK_STATE_UNLOCKING\x10\x05*<\n\x0bLockCommand\x12\x0f\n\x0bLOCK_UNLOCK\x10\x00\x12\r\n\tLOCK_LOCK\x10\x01\x12\r\n\tLOCK_OPEN\x10\x02*\xe5\x01\n\x10MediaPlayerState\x12\x1b\n\x17MEDIA_PLAYER_STATE_NONE\x10\x00\x12\x1b\n\x17MEDIA_PLAYER_STATE_IDLE\x10\x01\x12\x1e\n\x1aMEDIA_PLAYER_STATE_PLAYING\x10\x02\x12\x1d\n\x19MEDIA_PLAYER_STATE_PAUSED\x10\x03\x12!\n\x1dMEDIA_PLAYER_STATE_ANNOUNCING\x10\x04\x12\x1a\n\x16MEDIA_PLAYER_STATE_OFF\x10\x05\x12\x19\n\x15MEDIA_PLAYER_STATE_ON\x10\x06*\xf7\x03\n\x12MediaPlayerCommand\x12\x1d\n\x19MEDIA_PLAYER_COMMAND_PLAY\x10\x00\x12\x1e\n\x1aMEDIA_PLAYER_COMMAND_PAUSE\x10\x01\x12\x1d\n\x19MEDIA_PLAYER_COMMAND_STOP\x10\x02\x12\x1d\n\x19MEDIA_PLAYER_COMMAND_MUTE\x10\x03\x12\x1f\n\x1bMEDIA_PLAYER_COMMAND_UNMUTE\x10\x04\x12\x1f\n\x1bMEDIA_PLAYER_COMMAND_TOGGLE\x10\x05\x12\"\n\x1eMEDIA_PLAYER_COMMAND_VOLUME_UP\x10\x06\x12$\n MEDIA_PLAYER_COMMAND_VOLUME_DOWN\x10\x07\x12 \n\x1cMEDIA_PLAYER_COMMAND_ENQUEUE\x10\x08\x12#\n\x1fMEDIA_PLAYER_COMMAND_REPEAT_ONE\x10\t\x12#\n\x1fMEDIA_PLAYER_COMMAND_REPEAT_OFF\x10\n\x12\'\n#MEDIA_PLAYER_COMMAND_CLEAR_PLAYLIST\x10\x0b\x12 \n\x1cMEDIA_PLAYER_COMMAND_TURN_ON\x10\x0c\x12!\n\x1dMEDIA_PLAYER_COMMAND_TURN_OFF\x10\r*q\n\x18MediaPlayerFormatPurpose\x12\'\n#MEDIA_PLAYER_FORMAT_PURPOSE_DEFAULT\x10\x00\x12,\n(MEDIA_PLAYER_FORMAT_PURPOSE_ANNOUNCEMENT\x10\x01*\xef\x02\n\x1a\x42luetoothDeviceRequestType\x12-\n%BLUETOOTH_DEVICE_REQUEST_TYPE_CONNECT\x10\x00\x1a\x02\x08\x01\x12,\n(BLUETOOTH_DEVICE_REQUEST_TYPE_DISCONNECT\x10\x01\x12&\n\"BLUETOOTH_DEVICE_REQUEST_TYPE_PAIR\x10\x02\x12(\n$BLUETOOTH_DEVICE_REQUEST_TYPE_UNPAIR\x10\x03\x12\x37\n3BLUETOOTH_DEVICE_REQUEST_TYPE_CONNECT_V3_WITH_CACHE\x10\x04\x12:\n6BLUETOOTH_DEVICE_REQUEST_TYPE_CONNECT_V3_WITHOUT_CACHE\x10\x05\x12-\n)BLUETOOTH_DEVICE_REQUEST_TYPE_CLEAR_CACHE\x10\x06*\xf3\x01\n\x15\x42luetoothScannerState\x12 \n\x1c\x42LUETOOTH_SCANNER_STATE_IDLE\x10\x00\x12$\n BLUETOOTH_SCANNER_STATE_STARTING\x10\x01\x12#\n\x1f\x42LUETOOTH_SCANNER_STATE_RUNNING\x10\x02\x12\"\n\x1e\x42LUETOOTH_SCANNER_STATE_FAILED\x10\x03\x12$\n BLUETOOTH_SCANNER_STATE_STOPPING\x10\x04\x12#\n\x1f\x42LUETOOTH_SCANNER_STATE_STOPPED\x10\x05*]\n\x14\x42luetoothScannerMode\x12\"\n\x1e\x42LUETOOTH_SCANNER_MODE_PASSIVE\x10\x00\x12!\n\x1d\x42LUETOOTH_SCANNER_MODE_ACTIVE\x10\x01*j\n\x1bVoiceAssistantSubscribeFlag\x12\"\n\x1eVOICE_ASSISTANT_SUBSCRIBE_NONE\x10\x00\x12\'\n#VOICE_ASSISTANT_SUBSCRIBE_API_AUDIO\x10\x01*\x8d\x01\n\x19VoiceAssistantRequestFlag\x12 \n\x1cVOICE_ASSISTANT_REQUEST_NONE\x10\x00\x12#\n\x1fVOICE_ASSISTANT_REQUEST_USE_VAD\x10\x01\x12)\n%VOICE_ASSISTANT_REQUEST_USE_WAKE_WORD\x10\x02*\xa1\x04\n\x13VoiceAssistantEvent\x12\x19\n\x15VOICE_ASSISTANT_ERROR\x10\x00\x12\x1d\n\x19VOICE_ASSISTANT_RUN_START\x10\x01\x12\x1b\n\x17VOICE_ASSISTANT_RUN_END\x10\x02\x12\x1d\n\x19VOICE_ASSISTANT_STT_START\x10\x03\x12\x1b\n\x17VOICE_ASSISTANT_STT_END\x10\x04\x12 \n\x1cVOICE_ASSISTANT_INTENT_START\x10\x05\x12\x1e\n\x1aVOICE_ASSISTANT_INTENT_END\x10\x06\x12\x1d\n\x19VOICE_ASSISTANT_TTS_START\x10\x07\x12\x1b\n\x17VOICE_ASSISTANT_TTS_END\x10\x08\x12#\n\x1fVOICE_ASSISTANT_WAKE_WORD_START\x10\t\x12!\n\x1dVOICE_ASSISTANT_WAKE_WORD_END\x10\n\x12!\n\x1dVOICE_ASSISTANT_STT_VAD_START\x10\x0b\x12\x1f\n\x1bVOICE_ASSISTANT_STT_VAD_END\x10\x0c\x12$\n VOICE_ASSISTANT_TTS_STREAM_START\x10\x62\x12\"\n\x1eVOICE_ASSISTANT_TTS_STREAM_END\x10\x63\x12#\n\x1fVOICE_ASSISTANT_INTENT_PROGRESS\x10\x64*\xa9\x01\n\x18VoiceAssistantTimerEvent\x12!\n\x1dVOICE_ASSISTANT_TIMER_STARTED\x10\x00\x12!\n\x1dVOICE_ASSISTANT_TIMER_UPDATED\x10\x01\x12#\n\x1fVOICE_ASSISTANT_TIMER_CANCELLED\x10\x02\x12\"\n\x1eVOICE_ASSISTANT_TIMER_FINISHED\x10\x03*\xb3\x02\n\x16\x41larmControlPanelState\x12\x18\n\x14\x41LARM_STATE_DISARMED\x10\x00\x12\x1a\n\x16\x41LARM_STATE_ARMED_HOME\x10\x01\x12\x1a\n\x16\x41LARM_STATE_ARMED_AWAY\x10\x02\x12\x1b\n\x17\x41LARM_STATE_ARMED_NIGHT\x10\x03\x12\x1e\n\x1a\x41LARM_STATE_ARMED_VACATION\x10\x04\x12#\n\x1f\x41LARM_STATE_ARMED_CUSTOM_BYPASS\x10\x05\x12\x17\n\x13\x41LARM_STATE_PENDING\x10\x06\x12\x16\n\x12\x41LARM_STATE_ARMING\x10\x07\x12\x19\n\x15\x41LARM_STATE_DISARMING\x10\x08\x12\x19\n\x15\x41LARM_STATE_TRIGGERED\x10\t*\x98\x02\n\x1d\x41larmControlPanelStateCommand\x12\x1e\n\x1a\x41LARM_CONTROL_PANEL_DISARM\x10\x00\x12 \n\x1c\x41LARM_CONTROL_PANEL_ARM_AWAY\x10\x01\x12 \n\x1c\x41LARM_CONTROL_PANEL_ARM_HOME\x10\x02\x12!\n\x1d\x41LARM_CONTROL_PANEL_ARM_NIGHT\x10\x03\x12$\n ALARM_CONTROL_PANEL_ARM_VACATION\x10\x04\x12)\n%ALARM_CONTROL_PANEL_ARM_CUSTOM_BYPASS\x10\x05\x12\x1f\n\x1b\x41LARM_CONTROL_PANEL_TRIGGER\x10\x06*6\n\x08TextMode\x12\x12\n\x0eTEXT_MODE_TEXT\x10\x00\x12\x16\n\x12TEXT_MODE_PASSWORD\x10\x01*j\n\x0eValveOperation\x12\x18\n\x14VALVE_OPERATION_IDLE\x10\x00\x12\x1e\n\x1aVALVE_OPERATION_IS_OPENING\x10\x01\x12\x1e\n\x1aVALVE_OPERATION_IS_CLOSING\x10\x02*]\n\rUpdateCommand\x12\x17\n\x13UPDATE_COMMAND_NONE\x10\x00\x12\x19\n\x15UPDATE_COMMAND_UPDATE\x10\x01\x12\x18\n\x14UPDATE_COMMAND_CHECK\x10\x02*\x96\x01\n\x15ZWaveProxyRequestType\x12&\n\"ZWAVE_PROXY_REQUEST_TYPE_SUBSCRIBE\x10\x00\x12(\n$ZWAVE_PROXY_REQUEST_TYPE_UNSUBSCRIBE\x10\x01\x12+\n\'ZWAVE_PROXY_REQUEST_TYPE_HOME_ID_CHANGE\x10\x02*l\n\x11SerialProxyParity\x12\x1c\n\x18SERIAL_PROXY_PARITY_NONE\x10\x00\x12\x1c\n\x18SERIAL_PROXY_PARITY_EVEN\x10\x01\x12\x1b\n\x17SERIAL_PROXY_PARITY_ODD\x10\x02*\x91\x01\n\x16SerialProxyRequestType\x12\'\n#SERIAL_PROXY_REQUEST_TYPE_SUBSCRIBE\x10\x00\x12)\n%SERIAL_PROXY_REQUEST_TYPE_UNSUBSCRIBE\x10\x01\x12#\n\x1fSERIAL_PROXY_REQUEST_TYPE_FLUSH\x10\x02*\xbf\x01\n\x11SerialProxyStatus\x12\x1a\n\x16SERIAL_PROXY_STATUS_OK\x10\x00\x12\'\n#SERIAL_PROXY_STATUS_ASSUMED_SUCCESS\x10\x01\x12\x1d\n\x19SERIAL_PROXY_STATUS_ERROR\x10\x02\x12\x1f\n\x1bSERIAL_PROXY_STATUS_TIMEOUT\x10\x03\x12%\n!SERIAL_PROXY_STATUS_NOT_SUPPORTED\x10\x04\x32\x86\x1b\n\rAPIConnection\x12.\n\x05hello\x12\r.HelloRequest\x1a\x0e.HelloResponse\"\x06\xf0@\x00\xf8@\x00\x12=\n\ndisconnect\x12\x12.DisconnectRequest\x1a\x13.DisconnectResponse\"\x06\xf0@\x00\xf8@\x00\x12+\n\x04ping\x12\x0c.PingRequest\x1a\r.PingResponse\"\x06\xf0@\x00\xf8@\x00\x12;\n\x0b\x64\x65vice_info\x12\x12.DeviceInfoRequest\x1a\x13.DeviceInfoResponse\"\x03\xf8@\x00\x12.\n\rlist_entities\x12\x14.ListEntitiesRequest\x1a\x05.void\"\x00\x12\x34\n\x10subscribe_states\x12\x17.SubscribeStatesRequest\x1a\x05.void\"\x00\x12\x30\n\x0esubscribe_logs\x12\x15.SubscribeLogsRequest\x1a\x05.void\"\x00\x12S\n subscribe_homeassistant_services\x12&.SubscribeHomeassistantServicesRequest\x1a\x05.void\"\x00\x12P\n\x1fsubscribe_home_assistant_states\x12$.SubscribeHomeAssistantStatesRequest\x1a\x05.void\"\x00\x12\x32\n\x0f\x65xecute_service\x12\x16.ExecuteServiceRequest\x1a\x05.void\"\x00\x12[\n\x18noise_encryption_set_key\x12\x1d.NoiseEncryptionSetKeyRequest\x1a\x1e.NoiseEncryptionSetKeyResponse\"\x00\x12\x30\n\x0e\x62utton_command\x12\x15.ButtonCommandRequest\x1a\x05.void\"\x00\x12,\n\x0c\x63\x61mera_image\x12\x13.CameraImageRequest\x1a\x05.void\"\x00\x12\x32\n\x0f\x63limate_command\x12\x16.ClimateCommandRequest\x1a\x05.void\"\x00\x12.\n\rcover_command\x12\x14.CoverCommandRequest\x1a\x05.void\"\x00\x12,\n\x0c\x64\x61te_command\x12\x13.DateCommandRequest\x1a\x05.void\"\x00\x12\x34\n\x10\x64\x61tetime_command\x12\x17.DateTimeCommandRequest\x1a\x05.void\"\x00\x12*\n\x0b\x66\x61n_command\x12\x12.FanCommandRequest\x1a\x05.void\"\x00\x12.\n\rlight_command\x12\x14.LightCommandRequest\x1a\x05.void\"\x00\x12,\n\x0clock_command\x12\x13.LockCommandRequest\x1a\x05.void\"\x00\x12;\n\x14media_player_command\x12\x1a.MediaPlayerCommandRequest\x1a\x05.void\"\x00\x12\x30\n\x0enumber_command\x12\x15.NumberCommandRequest\x1a\x05.void\"\x00\x12\x30\n\x0eselect_command\x12\x15.SelectCommandRequest\x1a\x05.void\"\x00\x12.\n\rsiren_command\x12\x14.SirenCommandRequest\x1a\x05.void\"\x00\x12\x30\n\x0eswitch_command\x12\x15.SwitchCommandRequest\x1a\x05.void\"\x00\x12,\n\x0ctext_command\x12\x13.TextCommandRequest\x1a\x05.void\"\x00\x12,\n\x0ctime_command\x12\x13.TimeCommandRequest\x1a\x05.void\"\x00\x12\x30\n\x0eupdate_command\x12\x15.UpdateCommandRequest\x1a\x05.void\"\x00\x12.\n\rvalve_command\x12\x14.ValveCommandRequest\x1a\x05.void\"\x00\x12;\n\x14water_heater_command\x12\x1a.WaterHeaterCommandRequest\x1a\x05.void\"\x00\x12\\\n%subscribe_bluetooth_le_advertisements\x12*.SubscribeBluetoothLEAdvertisementsRequest\x1a\x05.void\"\x00\x12<\n\x18\x62luetooth_device_request\x12\x17.BluetoothDeviceRequest\x1a\x05.void\"\x00\x12H\n\x1b\x62luetooth_gatt_get_services\x12 .BluetoothGATTGetServicesRequest\x1a\x05.void\"\x00\x12\x39\n\x13\x62luetooth_gatt_read\x12\x19.BluetoothGATTReadRequest\x1a\x05.void\"\x00\x12;\n\x14\x62luetooth_gatt_write\x12\x1a.BluetoothGATTWriteRequest\x1a\x05.void\"\x00\x12N\n\x1e\x62luetooth_gatt_read_descriptor\x12#.BluetoothGATTReadDescriptorRequest\x1a\x05.void\"\x00\x12P\n\x1f\x62luetooth_gatt_write_descriptor\x12$.BluetoothGATTWriteDescriptorRequest\x1a\x05.void\"\x00\x12=\n\x15\x62luetooth_gatt_notify\x12\x1b.BluetoothGATTNotifyRequest\x1a\x05.void\"\x00\x12v\n$subscribe_bluetooth_connections_free\x12).SubscribeBluetoothConnectionsFreeRequest\x1a!.BluetoothConnectionsFreeResponse\"\x00\x12`\n\'unsubscribe_bluetooth_le_advertisements\x12,.UnsubscribeBluetoothLEAdvertisementsRequest\x1a\x05.void\"\x00\x12\x46\n\x1a\x62luetooth_scanner_set_mode\x12\x1f.BluetoothScannerSetModeRequest\x1a\x05.void\"\x00\x12p\n\x1f\x62luetooth_set_connection_params\x12$.BluetoothSetConnectionParamsRequest\x1a%.BluetoothSetConnectionParamsResponse\"\x00\x12\x45\n\x19subscribe_voice_assistant\x12\x1f.SubscribeVoiceAssistantRequest\x1a\x05.void\"\x00\x12p\n!voice_assistant_get_configuration\x12#.VoiceAssistantConfigurationRequest\x1a$.VoiceAssistantConfigurationResponse\"\x00\x12M\n!voice_assistant_set_configuration\x12\x1f.VoiceAssistantSetConfiguration\x1a\x05.void\"\x00\x12H\n\x1b\x61larm_control_panel_command\x12 .AlarmControlPanelCommandRequest\x1a\x05.void\"\x00\x12.\n\x11zwave_proxy_frame\x12\x10.ZWaveProxyFrame\x1a\x05.void\"\x00\x12\x32\n\x13zwave_proxy_request\x12\x12.ZWaveProxyRequest\x1a\x05.void\"\x00\x12Q\n infrared_rf_transmit_raw_timings\x12$.InfraredRFTransmitRawTimingsRequest\x1a\x05.void\"\x00\x12?\n\x16serial_proxy_configure\x12\x1c.SerialProxyConfigureRequest\x1a\x05.void\"\x00\x12\x37\n\x12serial_proxy_write\x12\x18.SerialProxyWriteRequest\x1a\x05.void\"\x00\x12G\n\x1bserial_proxy_set_modem_pins\x12\x1f.SerialProxySetModemPinsRequest\x1a\x05.void\"\x00\x12G\n\x1bserial_proxy_get_modem_pins\x12\x1f.SerialProxyGetModemPinsRequest\x1a\x05.void\"\x00\x12\x34\n\x14serial_proxy_request\x12\x13.SerialProxyRequest\x1a\x05.void\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LEGACYCOVERSTATE']._loaded_options = None
  _globals['_LEGACYCOVERSTATE']._serialized_options = b'\030\001'
  _globals['_LEGACYCOVERCOMMAND']._loaded_options = None
  _globals['_LEGACYCOVERCOMMAND']._serialized_options = b'\030\001'
  _globals['_FANSPEED']._loaded_options = None
  _globals['_FANSPEED']._serialized_options = b'\030\001'
  _globals['_SENSORLASTRESETTYPE']._loaded_options = None
  _globals['_SENSORLASTRESETTYPE']._serialized_options = b'\030\001'
  _globals['_WATERHEATERCOMMANDHASFIELD'].values_by_name["WATER_HEATER_COMMAND_HAS_STATE"]._loaded_options = None
  _globals['_WATERHEATERCOMMANDHASFIELD'].values_by_name["WATER_HEATER_COMMAND_HAS_STATE"]._serialized_options = b'\010\001'
  _globals['_BLUETOOTHDEVICEREQUESTTYPE'].values_by_name["BLUETOOTH_DEVICE_REQUEST_TYPE_CONNECT"]._loaded_options = None
  _globals['_BLUETOOTHDEVICEREQUESTTYPE'].values_by_name["BLUETOOTH_DEVICE_REQUEST_TYPE_CONNECT"]._serialized_options = b'\010\001'
  _globals['_HELLOREQUEST']._loaded_options = None
  _globals['_HELLOREQUEST']._serialized_options = b'\340@\001\350@\002\200A\001'
  _globals['_HELLORESPONSE']._loaded_options = None
  _globals['_HELLORESPONSE']._serialized_options = b'\340@\002\350@\001\200A\001'
  _globals['_AUTHENTICATIONREQUEST']._loaded_options = None
  _globals['_AUTHENTICATIONREQUEST']._serialized_options = b'\030\001\340@\003\350@\002\200A\001'
  _globals['_AUTHENTICATIONRESPONSE']._loaded_options = None
  _globals['_AUTHENTICATIONRESPONSE']._serialized_options = b'\030\001\340@\004\350@\001\200A\001'
  _globals['_DISCONNECTREQUEST']._loaded_options = None
  _globals['_DISCONNECTREQUEST']._serialized_options = b'\340@\005\350@\000\200A\001'
  _globals['_DISCONNECTRESPONSE']._loaded_options = None
  _globals['_DISCONNECTRESPONSE']._serialized_options = b'\340@\006\350@\000\200A\001'
  _globals['_PINGREQUEST']._loaded_options = None
  _globals['_PINGREQUEST']._serialized_options = b'\340@\007\350@\000'
  _globals['_PINGRESPONSE']._loaded_options = None
  _globals['_PINGRESPONSE']._serialized_options = b'\340@\010\350@\000'
  _globals['_DEVICEINFOREQUEST']._loaded_options = None
  _globals['_DEVICEINFOREQUEST']._serialized_options = b'\340@\t\350@\002'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['uses_password']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['uses_password']._serialized_options = b'\030\001'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['has_deep_sleep']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['has_deep_sleep']._serialized_options = b'\222A\016USE_DEEP_SLEEP'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['project_name']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['project_name']._serialized_options = b'\222A\024ESPHOME_PROJECT_NAME'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['project_version']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['project_version']._serialized_options = b'\222A\024ESPHOME_PROJECT_NAME'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['webserver_port']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['webserver_port']._serialized_options = b'\222A\rUSE_WEBSERVER'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['legacy_bluetooth_proxy_version']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['legacy_bluetooth_proxy_version']._serialized_options = b'\030\001\222A\023USE_BLUETOOTH_PROXY'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['bluetooth_proxy_feature_flags']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['bluetooth_proxy_feature_flags']._serialized_options = b'\222A\023USE_BLUETOOTH_PROXY'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['legacy_voice_assistant_version']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['legacy_voice_assistant_version']._serialized_options = b'\030\001\222A\023USE_VOICE_ASSISTANT'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['voice_assistant_feature_flags']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['voice_assistant_feature_flags']._serialized_options = b'\222A\023USE_VOICE_ASSISTANT'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['suggested_area']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['suggested_area']._serialized_options = b'\222A\tUSE_AREAS'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['bluetooth_mac_address']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['bluetooth_mac_address']._serialized_options = b'\222A\023USE_BLUETOOTH_PROXY'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['api_encryption_supported']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['api_encryption_supported']._serialized_options = b'\222A\rUSE_API_NOISE'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['devices']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['devices']._serialized_options = b'\222A\013USE_DEVICES\322\265\030\024ESPHOME_DEVICE_COUNT'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['areas']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['areas']._serialized_options = b'\222A\tUSE_AREAS\322\265\030\022ESPHOME_AREA_COUNT'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['area']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['area']._serialized_options = b'\222A\tUSE_AREAS'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['zwave_proxy_feature_flags']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['zwave_proxy_feature_flags']._serialized_options = b'\222A\017USE_ZWAVE_PROXY'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['zwave_home_id']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['zwave_home_id']._serialized_options = b'\222A\017USE_ZWAVE_PROXY'
  _globals['_DEVICEINFORESPONSE'].fields_by_name['serial_proxies']._loaded_options = None
  _globals['_DEVICEINFORESPONSE'].fields_by_name['serial_proxies']._serialized_options = b'\222A\020USE_SERIAL_PROXY\322\265\030\022SERIAL_PROXY_COUNT'
  _globals['_DEVICEINFORESPONSE']._loaded_options = None
  _globals['_DEVICEINFORESPONSE']._serialized_options = b'\340@\n\350@\001'
  _globals['_LISTENTITIESREQUEST']._loaded_options = None
  _globals['_LISTENTITIESREQUEST']._serialized_options = b'\340@\013\350@\002'
  _globals['_LISTENTITIESDONERESPONSE']._loaded_options = None
  _globals['_LISTENTITIESDONERESPONSE']._serialized_options = b'\340@\023\350@\001\200A\001'
  _globals['_SUBSCRIBESTATESREQUEST']._loaded_options = None
  _globals['_SUBSCRIBESTATESREQUEST']._serialized_options = b'\340@\024\350@\002'
  _globals['_LISTENTITIESBINARYSENSORRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESBINARYSENSORRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESBINARYSENSORRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESBINARYSENSORRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESBINARYSENSORRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESBINARYSENSORRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESBINARYSENSORRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESBINARYSENSORRESPONSE']._serialized_options = b'\340@\014\350@\001\362@\021USE_BINARY_SENSOR\212A\030InfoResponseProtoMessage'
  _globals['_BINARYSENSORSTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_BINARYSENSORSTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_BINARYSENSORSTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_BINARYSENSORSTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_BINARYSENSORSTATERESPONSE']._loaded_options = None
  _globals['_BINARYSENSORSTATERESPONSE']._serialized_options = b'\340@\025\350@\001\362@\021USE_BINARY_SENSOR\200A\001\212A\031StateResponseProtoMessage'
  _globals['_LISTENTITIESCOVERRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESCOVERRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESCOVERRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESCOVERRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESCOVERRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESCOVERRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESCOVERRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESCOVERRESPONSE']._serialized_options = b'\340@\r\350@\001\362@\tUSE_COVER\212A\030InfoResponseProtoMessage'
  _globals['_COVERSTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_COVERSTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_COVERSTATERESPONSE'].fields_by_name['legacy_state']._loaded_options = None
  _globals['_COVERSTATERESPONSE'].fields_by_name['legacy_state']._serialized_options = b'\030\001'
  _globals['_COVERSTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_COVERSTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_COVERSTATERESPONSE']._loaded_options = None
  _globals['_COVERSTATERESPONSE']._serialized_options = b'\340@\026\350@\001\362@\tUSE_COVER\200A\001\212A\031StateResponseProtoMessage'
  _globals['_COVERCOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_COVERCOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_COVERCOMMANDREQUEST'].fields_by_name['has_legacy_command']._loaded_options = None
  _globals['_COVERCOMMANDREQUEST'].fields_by_name['has_legacy_command']._serialized_options = b'\030\001'
  _globals['_COVERCOMMANDREQUEST'].fields_by_name['legacy_command']._loaded_options = None
  _globals['_COVERCOMMANDREQUEST'].fields_by_name['legacy_command']._serialized_options = b'\030\001'
  _globals['_COVERCOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_COVERCOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_COVERCOMMANDREQUEST']._loaded_options = None
  _globals['_COVERCOMMANDREQUEST']._serialized_options = b'\340@\036\350@\002\362@\tUSE_COVER\200A\001\212A\023CommandProtoMessage'
  _globals['_LISTENTITIESFANRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESFANRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESFANRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESFANRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESFANRESPONSE'].fields_by_name['supported_preset_modes']._loaded_options = None
  _globals['_LISTENTITIESFANRESPONSE'].fields_by_name['supported_preset_modes']._serialized_options = b'\362\265\030\031std::vector<const char *>'
  _globals['_LISTENTITIESFANRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESFANRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESFANRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESFANRESPONSE']._serialized_options = b'\340@\016\350@\001\362@\007USE_FAN\212A\030InfoResponseProtoMessage'
  _globals['_FANSTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_FANSTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_FANSTATERESPONSE'].fields_by_name['speed']._loaded_options = None
  _globals['_FANSTATERESPONSE'].fields_by_name['speed']._serialized_options = b'\030\001'
  _globals['_FANSTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_FANSTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_FANSTATERESPONSE']._loaded_options = None
  _globals['_FANSTATERESPONSE']._serialized_options = b'\340@\027\350@\001\362@\007USE_FAN\200A\001\212A\031StateResponseProtoMessage'
  _globals['_FANCOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_FANCOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_FANCOMMANDREQUEST'].fields_by_name['has_speed']._loaded_options = None
  _globals['_FANCOMMANDREQUEST'].fields_by_name['has_speed']._serialized_options = b'\030\001'
  _globals['_FANCOMMANDREQUEST'].fields_by_name['speed']._loaded_options = None
  _globals['_FANCOMMANDREQUEST'].fields_by_name['speed']._serialized_options = b'\030\001'
  _globals['_FANCOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_FANCOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_FANCOMMANDREQUEST']._loaded_options = None
  _globals['_FANCOMMANDREQUEST']._serialized_options = b'\340@\037\350@\002\362@\007USE_FAN\200A\001\212A\023CommandProtoMessage'
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['supported_color_modes']._loaded_options = None
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['supported_color_modes']._serialized_options = b'\362\265\030\024light::ColorModeMask'
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['legacy_supports_brightness']._loaded_options = None
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['legacy_supports_brightness']._serialized_options = b'\030\001'
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['legacy_supports_rgb']._loaded_options = None
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['legacy_supports_rgb']._serialized_options = b'\030\001'
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['legacy_supports_white_value']._loaded_options = None
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['legacy_supports_white_value']._serialized_options = b'\030\001'
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['legacy_supports_color_temperature']._loaded_options = None
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['legacy_supports_color_temperature']._serialized_options = b'\030\001'
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['effects']._loaded_options = None
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['effects']._serialized_options = b'\362\265\030\031FixedVector<const char *>'
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESLIGHTRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESLIGHTRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESLIGHTRESPONSE']._serialized_options = b'\340@\017\350@\001\362@\tUSE_LIGHT\212A\030InfoResponseProtoMessage'
  _globals['_LIGHTSTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LIGHTSTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LIGHTSTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LIGHTSTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LIGHTSTATERESPONSE']._loaded_options = None
  _globals['_LIGHTSTATERESPONSE']._serialized_options = b'\340@\030\350@\001\362@\tUSE_LIGHT\200A\001\212A\031StateResponseProtoMessage'
  _globals['_LIGHTCOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_LIGHTCOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LIGHTCOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_LIGHTCOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LIGHTCOMMANDREQUEST']._loaded_options = None
  _globals['_LIGHTCOMMANDREQUEST']._serialized_options = b'\340@ \350@\002\362@\tUSE_LIGHT\200A\001\212A\023CommandProtoMessage'
  _globals['_LISTENTITIESSENSORRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESSENSORRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESSENSORRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESSENSORRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESSENSORRESPONSE'].fields_by_name['legacy_last_reset_type']._loaded_options = None
  _globals['_LISTENTITIESSENSORRESPONSE'].fields_by_name['legacy_last_reset_type']._serialized_options = b'\030\001'
  _globals['_LISTENTITIESSENSORRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESSENSORRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESSENSORRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESSENSORRESPONSE']._serialized_options = b'\340@\020\350@\001\362@\nUSE_SENSOR\212A\030InfoResponseProtoMessage'
  _globals['_SENSORSTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_SENSORSTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_SENSORSTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_SENSORSTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_SENSORSTATERESPONSE']._loaded_options = None
  _globals['_SENSORSTATERESPONSE']._serialized_options = b'\340@\031\350@\001\362@\nUSE_SENSOR\200A\001\212A\031StateResponseProtoMessage'
  _globals['_LISTENTITIESSWITCHRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESSWITCHRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESSWITCHRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESSWITCHRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESSWITCHRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESSWITCHRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESSWITCHRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESSWITCHRESPONSE']._serialized_options = b'\340@\021\350@\001\362@\nUSE_SWITCH\212A\030InfoResponseProtoMessage'
  _globals['_SWITCHSTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_SWITCHSTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_SWITCHSTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_SWITCHSTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_SWITCHSTATERESPONSE']._loaded_options = None
  _globals['_SWITCHSTATERESPONSE']._serialized_options = b'\340@\032\350@\001\362@\nUSE_SWITCH\200A\001\212A\031StateResponseProtoMessage'
  _globals['_SWITCHCOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_SWITCHCOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_SWITCHCOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_SWITCHCOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_SWITCHCOMMANDREQUEST']._loaded_options = None
  _globals['_SWITCHCOMMANDREQUEST']._serialized_options = b'\340@!\350@\002\362@\nUSE_SWITCH\200A\001\212A\023CommandProtoMessage'
  _globals['_LISTENTITIESTEXTSENSORRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESTEXTSENSORRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESTEXTSENSORRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESTEXTSENSORRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESTEXTSENSORRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESTEXTSENSORRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESTEXTSENSORRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESTEXTSENSORRESPONSE']._serialized_options = b'\340@\022\350@\001\362@\017USE_TEXT_SENSOR\212A\030InfoResponseProtoMessage'
  _globals['_TEXTSENSORSTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_TEXTSENSORSTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_TEXTSENSORSTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_TEXTSENSORSTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_TEXTSENSORSTATERESPONSE']._loaded_options = None
  _globals['_TEXTSENSORSTATERESPONSE']._serialized_options = b'\340@\033\350@\001\362@\017USE_TEXT_SENSOR\200A\001\212A\031StateResponseProtoMessage'
  _globals['_SUBSCRIBELOGSREQUEST']._loaded_options = None
  _globals['_SUBSCRIBELOGSREQUEST']._serialized_options = b'\340@\034\350@\002'
  _globals['_SUBSCRIBELOGSRESPONSE']._loaded_options = None
  _globals['_SUBSCRIBELOGSRESPONSE']._serialized_options = b'\340@\035\350@\001\370@\000\200A\000'
  _globals['_NOISEENCRYPTIONSETKEYREQUEST']._loaded_options = None
  _globals['_NOISEENCRYPTIONSETKEYREQUEST']._serialized_options = b'\340@|\350@\002\362@\rUSE_API_NOISE'
  _globals['_NOISEENCRYPTIONSETKEYRESPONSE']._loaded_options = None
  _globals['_NOISEENCRYPTIONSETKEYRESPONSE']._serialized_options = b'\340@}\350@\001\362@\rUSE_API_NOISE'
  _globals['_SUBSCRIBEHOMEASSISTANTSERVICESREQUEST']._loaded_options = None
  _globals['_SUBSCRIBEHOMEASSISTANTSERVICESREQUEST']._serialized_options = b'\340@\"\350@\002\362@\036USE_API_HOMEASSISTANT_SERVICES'
  _globals['_HOMEASSISTANTACTIONREQUEST'].fields_by_name['data']._loaded_options = None
  _globals['_HOMEASSISTANTACTIONREQUEST'].fields_by_name['data']._serialized_options = b'\350\265\030\001'
  _globals['_HOMEASSISTANTACTIONREQUEST'].fields_by_name['data_template']._loaded_options = None
  _globals['_HOMEASSISTANTACTIONREQUEST'].fields_by_name['data_template']._serialized_options = b'\350\265\030\001'
  _globals['_HOMEASSISTANTACTIONREQUEST'].fields_by_name['variables']._loaded_options = None
  _globals['_HOMEASSISTANTACTIONREQUEST'].fields_by_name['variables']._serialized_options = b'\350\265\030\001'
  _globals['_HOMEASSISTANTACTIONREQUEST'].fields_by_name['call_id']._loaded_options = None
  _globals['_HOMEASSISTANTACTIONREQUEST'].fields_by_name['call_id']._serialized_options = b'\222A&USE_API_HOMEASSISTANT_ACTION_RESPONSES'
  _globals['_HOMEASSISTANTACTIONREQUEST'].fields_by_name['wants_response']._loaded_options = None
  _globals['_HOMEASSISTANTACTIONREQUEST'].fields_by_name['wants_response']._serialized_options = b'\222A+USE_API_HOMEASSISTANT_ACTION_RESPONSES_JSON'
  _globals['_HOMEASSISTANTACTIONREQUEST'].fields_by_name['response_template']._loaded_options = None
  _globals['_HOMEASSISTANTACTIONREQUEST'].fields_by_name['response_template']._serialized_options = b'\222A+USE_API_HOMEASSISTANT_ACTION_RESPONSES_JSON'
  _globals['_HOMEASSISTANTACTIONREQUEST']._loaded_options = None
  _globals['_HOMEASSISTANTACTIONREQUEST']._serialized_options = b'\340@#\350@\001\362@\036USE_API_HOMEASSISTANT_SERVICES\200A\001'
  _globals['_HOMEASSISTANTACTIONRESPONSE'].fields_by_name['response_data']._loaded_options = None
  _globals['_HOMEASSISTANTACTIONRESPONSE'].fields_by_name['response_data']._serialized_options = b'\222A+USE_API_HOMEASSISTANT_ACTION_RESPONSES_JSON'
  _globals['_HOMEASSISTANTACTIONRESPONSE']._loaded_options = None
  _globals['_HOMEASSISTANTACTIONRESPONSE']._serialized_options = b'\340@\202\001\350@\002\362@&USE_API_HOMEASSISTANT_ACTION_RESPONSES\200A\001'
  _globals['_SUBSCRIBEHOMEASSISTANTSTATESREQUEST']._loaded_options = None
  _globals['_SUBSCRIBEHOMEASSISTANTSTATESREQUEST']._serialized_options = b'\340@&\350@\002\362@\034USE_API_HOMEASSISTANT_STATES'
  _globals['_SUBSCRIBEHOMEASSISTANTSTATERESPONSE']._loaded_options = None
  _globals['_SUBSCRIBEHOMEASSISTANTSTATERESPONSE']._serialized_options = b'\340@\'\350@\001\362@\034USE_API_HOMEASSISTANT_STATES'
  _globals['_HOMEASSISTANTSTATERESPONSE']._loaded_options = None
  _globals['_HOMEASSISTANTSTATERESPONSE']._serialized_options = b'\340@(\350@\002\362@\034USE_API_HOMEASSISTANT_STATES\200A\001'
  _globals['_GETTIMEREQUEST']._loaded_options = None
  _globals['_GETTIMEREQUEST']._serialized_options = b'\340@$\350@\001'
  _globals['_DSTRULE']._loaded_options = None
  _globals['_DSTRULE']._serialized_options = b'\350@\002'
  _globals['_PARSEDTIMEZONE']._loaded_options = None
  _globals['_PARSEDTIMEZONE']._serialized_options = b'\350@\002'
  _globals['_GETTIMERESPONSE']._loaded_options = None
  _globals['_GETTIMERESPONSE']._serialized_options = b'\340@%\350@\002\200A\001'
  _globals['_LISTENTITIESSERVICESARGUMENT']._loaded_options = None
  _globals['_LISTENTITIESSERVICESARGUMENT']._serialized_options = b'\362@\034USE_API_USER_DEFINED_ACTIONS'
  _globals['_LISTENTITIESSERVICESRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESSERVICESRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESSERVICESRESPONSE'].fields_by_name['args']._loaded_options = None
  _globals['_LISTENTITIESSERVICESRESPONSE'].fields_by_name['args']._serialized_options = b'\350\265\030\001'
  _globals['_LISTENTITIESSERVICESRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESSERVICESRESPONSE']._serialized_options = b'\340@)\350@\001\362@\034USE_API_USER_DEFINED_ACTIONS'
  _globals['_EXECUTESERVICEARGUMENT'].fields_by_name['bool_array']._loaded_options = None
  _globals['_EXECUTESERVICEARGUMENT'].fields_by_name['bool_array']._serialized_options = b'\020\000\350\265\030\001'
  _globals['_EXECUTESERVICEARGUMENT'].fields_by_name['int_array']._loaded_options = None
  _globals['_EXECUTESERVICEARGUMENT'].fields_by_name['int_array']._serialized_options = b'\020\000\350\265\030\001'
  _globals['_EXECUTESERVICEARGUMENT'].fields_by_name['float_array']._loaded_options = None
  _globals['_EXECUTESERVICEARGUMENT'].fields_by_name['float_array']._serialized_options = b'\020\000\350\265\030\001'
  _globals['_EXECUTESERVICEARGUMENT'].fields_by_name['string_array']._loaded_options = None
  _globals['_EXECUTESERVICEARGUMENT'].fields_by_name['string_array']._serialized_options = b'\350\265\030\001'
  _globals['_EXECUTESERVICEARGUMENT']._loaded_options = None
  _globals['_EXECUTESERVICEARGUMENT']._serialized_options = b'\362@\034USE_API_USER_DEFINED_ACTIONS'
  _globals['_EXECUTESERVICEREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_EXECUTESERVICEREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_EXECUTESERVICEREQUEST'].fields_by_name['args']._loaded_options = None
  _globals['_EXECUTESERVICEREQUEST'].fields_by_name['args']._serialized_options = b'\350\265\030\001'
  _globals['_EXECUTESERVICEREQUEST'].fields_by_name['call_id']._loaded_options = None
  _globals['_EXECUTESERVICEREQUEST'].fields_by_name['call_id']._serialized_options = b'\222A%USE_API_USER_DEFINED_ACTION_RESPONSES'
  _globals['_EXECUTESERVICEREQUEST'].fields_by_name['return_response']._loaded_options = None
  _globals['_EXECUTESERVICEREQUEST'].fields_by_name['return_response']._serialized_options = b'\222A%USE_API_USER_DEFINED_ACTION_RESPONSES'
  _globals['_EXECUTESERVICEREQUEST']._loaded_options = None
  _globals['_EXECUTESERVICEREQUEST']._serialized_options = b'\340@*\350@\002\362@\034USE_API_USER_DEFINED_ACTIONS\200A\001'
  _globals['_EXECUTESERVICERESPONSE'].fields_by_name['response_data']._loaded_options = None
  _globals['_EXECUTESERVICERESPONSE'].fields_by_name['response_data']._serialized_options = b'\222A*USE_API_USER_DEFINED_ACTION_RESPONSES_JSON\340\265\030\001'
  _globals['_EXECUTESERVICERESPONSE']._loaded_options = None
  _globals['_EXECUTESERVICERESPONSE']._serialized_options = b'\340@\203\001\350@\001\362@%USE_API_USER_DEFINED_ACTION_RESPONSES\200A\001'
  _globals['_LISTENTITIESCAMERARESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESCAMERARESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESCAMERARESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESCAMERARESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESCAMERARESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESCAMERARESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESCAMERARESPONSE']._loaded_options = None
  _globals['_LISTENTITIESCAMERARESPONSE']._serialized_options = b'\340@+\350@\001\362@\nUSE_CAMERA\212A\030InfoResponseProtoMessage'
  _globals['_CAMERAIMAGERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_CAMERAIMAGERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_CAMERAIMAGERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_CAMERAIMAGERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_CAMERAIMAGERESPONSE']._loaded_options = None
  _globals['_CAMERAIMAGERESPONSE']._serialized_options = b'\340@,\350@\001\362@\nUSE_CAMERA\212A\031StateResponseProtoMessage'
  _globals['_CAMERAIMAGEREQUEST']._loaded_options = None
  _globals['_CAMERAIMAGEREQUEST']._serialized_options = b'\340@-\350@\002\362@\nUSE_CAMERA\200A\001'
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['supported_modes']._loaded_options = None
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['supported_modes']._serialized_options = b'\362\265\030\030climate::ClimateModeMask'
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['legacy_supports_away']._loaded_options = None
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['legacy_supports_away']._serialized_options = b'\030\001'
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['supported_fan_modes']._loaded_options = None
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['supported_fan_modes']._serialized_options = b'\362\265\030\033climate::ClimateFanModeMask'
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['supported_swing_modes']._loaded_options = None
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['supported_swing_modes']._serialized_options = b'\362\265\030\035climate::ClimateSwingModeMask'
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['supported_custom_fan_modes']._loaded_options = None
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['supported_custom_fan_modes']._serialized_options = b'\362\265\030\031std::vector<const char *>'
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['supported_presets']._loaded_options = None
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['supported_presets']._serialized_options = b'\362\265\030\032climate::ClimatePresetMask'
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['supported_custom_presets']._loaded_options = None
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['supported_custom_presets']._serialized_options = b'\362\265\030\031std::vector<const char *>'
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESCLIMATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESCLIMATERESPONSE']._loaded_options = None
  _globals['_LISTENTITIESCLIMATERESPONSE']._serialized_options = b'\340@.\350@\001\362@\013USE_CLIMATE\212A\030InfoResponseProtoMessage'
  _globals['_CLIMATESTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_CLIMATESTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_CLIMATESTATERESPONSE'].fields_by_name['unused_legacy_away']._loaded_options = None
  _globals['_CLIMATESTATERESPONSE'].fields_by_name['unused_legacy_away']._serialized_options = b'\030\001'
  _globals['_CLIMATESTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_CLIMATESTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_CLIMATESTATERESPONSE']._loaded_options = None
  _globals['_CLIMATESTATERESPONSE']._serialized_options = b'\340@/\350@\001\362@\013USE_CLIMATE\200A\001\212A\031StateResponseProtoMessage'
  _globals['_CLIMATECOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_CLIMATECOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_CLIMATECOMMANDREQUEST'].fields_by_name['unused_has_legacy_away']._loaded_options = None
  _globals['_CLIMATECOMMANDREQUEST'].fields_by_name['unused_has_legacy_away']._serialized_options = b'\030\001'
  _globals['_CLIMATECOMMANDREQUEST'].fields_by_name['unused_legacy_away']._loaded_options = None
  _globals['_CLIMATECOMMANDREQUEST'].fields_by_name['unused_legacy_away']._serialized_options = b'\030\001'
  _globals['_CLIMATECOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_CLIMATECOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_CLIMATECOMMANDREQUEST']._loaded_options = None
  _globals['_CLIMATECOMMANDREQUEST']._serialized_options = b'\340@0\350@\002\362@\013USE_CLIMATE\200A\001\212A\023CommandProtoMessage'
  _globals['_LISTENTITIESWATERHEATERRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESWATERHEATERRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESWATERHEATERRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESWATERHEATERRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESWATERHEATERRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESWATERHEATERRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESWATERHEATERRESPONSE'].fields_by_name['supported_modes']._loaded_options = None
  _globals['_LISTENTITIESWATERHEATERRESPONSE'].fields_by_name['supported_modes']._serialized_options = b'\362\265\030!water_heater::WaterHeaterModeMask'
  _globals['_LISTENTITIESWATERHEATERRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESWATERHEATERRESPONSE']._serialized_options = b'\340@\204\001\350@\001\362@\020USE_WATER_HEATER\212A\030InfoResponseProtoMessage'
  _globals['_WATERHEATERSTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_WATERHEATERSTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_WATERHEATERSTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_WATERHEATERSTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_WATERHEATERSTATERESPONSE']._loaded_options = None
  _globals['_WATERHEATERSTATERESPONSE']._serialized_options = b'\340@\205\001\350@\001\362@\020USE_WATER_HEATER\200A\001\212A\031StateResponseProtoMessage'
  _globals['_WATERHEATERCOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_WATERHEATERCOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_WATERHEATERCOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_WATERHEATERCOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_WATERHEATERCOMMANDREQUEST']._loaded_options = None
  _globals['_WATERHEATERCOMMANDREQUEST']._serialized_options = b'\340@\206\001\350@\002\362@\020USE_WATER_HEATER\200A\001\212A\023CommandProtoMessage'
  _globals['_LISTENTITIESNUMBERRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESNUMBERRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESNUMBERRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESNUMBERRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESNUMBERRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESNUMBERRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESNUMBERRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESNUMBERRESPONSE']._serialized_options = b'\340@1\350@\001\362@\nUSE_NUMBER\212A\030InfoResponseProtoMessage'
  _globals['_NUMBERSTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_NUMBERSTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_NUMBERSTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_NUMBERSTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_NUMBERSTATERESPONSE']._loaded_options = None
  _globals['_NUMBERSTATERESPONSE']._serialized_options = b'\340@2\350@\001\362@\nUSE_NUMBER\200A\001\212A\031StateResponseProtoMessage'
  _globals['_NUMBERCOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_NUMBERCOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_NUMBERCOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_NUMBERCOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_NUMBERCOMMANDREQUEST']._loaded_options = None
  _globals['_NUMBERCOMMANDREQUEST']._serialized_options = b'\340@3\350@\002\362@\nUSE_NUMBER\200A\001\212A\023CommandProtoMessage'
  _globals['_LISTENTITIESSELECTRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESSELECTRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESSELECTRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESSELECTRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESSELECTRESPONSE'].fields_by_name['options']._loaded_options = None
  _globals['_LISTENTITIESSELECTRESPONSE'].fields_by_name['options']._serialized_options = b'\362\265\030\031FixedVector<const char *>'
  _globals['_LISTENTITIESSELECTRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESSELECTRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESSELECTRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESSELECTRESPONSE']._serialized_options = b'\340@4\350@\001\362@\nUSE_SELECT\212A\030InfoResponseProtoMessage'
  _globals['_SELECTSTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_SELECTSTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_SELECTSTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_SELECTSTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_SELECTSTATERESPONSE']._loaded_options = None
  _globals['_SELECTSTATERESPONSE']._serialized_options = b'\340@5\350@\001\362@\nUSE_SELECT\200A\001\212A\031StateResponseProtoMessage'
  _globals['_SELECTCOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_SELECTCOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_SELECTCOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_SELECTCOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_SELECTCOMMANDREQUEST']._loaded_options = None
  _globals['_SELECTCOMMANDREQUEST']._serialized_options = b'\340@6\350@\002\362@\nUSE_SELECT\200A\001\212A\023CommandProtoMessage'
  _globals['_LISTENTITIESSIRENRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESSIRENRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESSIRENRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESSIRENRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESSIRENRESPONSE'].fields_by_name['tones']._loaded_options = None
  _globals['_LISTENTITIESSIRENRESPONSE'].fields_by_name['tones']._serialized_options = b'\362\265\030\031FixedVector<const char *>'
  _globals['_LISTENTITIESSIRENRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESSIRENRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESSIRENRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESSIRENRESPONSE']._serialized_options = b'\340@7\350@\001\362@\tUSE_SIREN\212A\030InfoResponseProtoMessage'
  _globals['_SIRENSTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_SIRENSTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_SIRENSTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_SIRENSTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_SIRENSTATERESPONSE']._loaded_options = None
  _globals['_SIRENSTATERESPONSE']._serialized_options = b'\340@8\350@\001\362@\tUSE_SIREN\200A\001\212A\031StateResponseProtoMessage'
  _globals['_SIRENCOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_SIRENCOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_SIRENCOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_SIRENCOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_SIRENCOMMANDREQUEST']._loaded_options = None
  _globals['_SIRENCOMMANDREQUEST']._serialized_options = b'\340@9\350@\002\362@\tUSE_SIREN\200A\001\212A\023CommandProtoMessage'
  _globals['_LISTENTITIESLOCKRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESLOCKRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESLOCKRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESLOCKRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESLOCKRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESLOCKRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESLOCKRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESLOCKRESPONSE']._serialized_options = b'\340@:\350@\001\362@\010USE_LOCK\212A\030InfoResponseProtoMessage'
  _globals['_LOCKSTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LOCKSTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LOCKSTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LOCKSTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LOCKSTATERESPONSE']._loaded_options = None
  _globals['_LOCKSTATERESPONSE']._serialized_options = b'\340@;\350@\001\362@\010USE_LOCK\200A\001\212A\031StateResponseProtoMessage'
  _globals['_LOCKCOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_LOCKCOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LOCKCOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_LOCKCOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LOCKCOMMANDREQUEST']._loaded_options = None
  _globals['_LOCKCOMMANDREQUEST']._serialized_options = b'\340@<\350@\002\362@\010USE_LOCK\200A\001\212A\023CommandProtoMessage'
  _globals['_LISTENTITIESBUTTONRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESBUTTONRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESBUTTONRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESBUTTONRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESBUTTONRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESBUTTONRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESBUTTONRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESBUTTONRESPONSE']._serialized_options = b'\340@=\350@\001\362@\nUSE_BUTTON\212A\030InfoResponseProtoMessage'
  _globals['_BUTTONCOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_BUTTONCOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_BUTTONCOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_BUTTONCOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_BUTTONCOMMANDREQUEST']._loaded_options = None
  _globals['_BUTTONCOMMANDREQUEST']._serialized_options = b'\340@>\350@\002\362@\nUSE_BUTTON\200A\001\212A\023CommandProtoMessage'
  _globals['_MEDIAPLAYERSUPPORTEDFORMAT']._loaded_options = None
  _globals['_MEDIAPLAYERSUPPORTEDFORMAT']._serialized_options = b'\362@\020USE_MEDIA_PLAYER'
  _globals['_LISTENTITIESMEDIAPLAYERRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESMEDIAPLAYERRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESMEDIAPLAYERRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESMEDIAPLAYERRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESMEDIAPLAYERRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESMEDIAPLAYERRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESMEDIAPLAYERRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESMEDIAPLAYERRESPONSE']._serialized_options = b'\340@?\350@\001\362@\020USE_MEDIA_PLAYER\212A\030InfoResponseProtoMessage'
  _globals['_MEDIAPLAYERSTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_MEDIAPLAYERSTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_MEDIAPLAYERSTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_MEDIAPLAYERSTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_MEDIAPLAYERSTATERESPONSE']._loaded_options = None
  _globals['_MEDIAPLAYERSTATERESPONSE']._serialized_options = b'\340@@\350@\001\362@\020USE_MEDIA_PLAYER\200A\001\212A\031StateResponseProtoMessage'
  _globals['_MEDIAPLAYERCOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_MEDIAPLAYERCOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_MEDIAPLAYERCOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_MEDIAPLAYERCOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_MEDIAPLAYERCOMMANDREQUEST']._loaded_options = None
  _globals['_MEDIAPLAYERCOMMANDREQUEST']._serialized_options = b'\340@A\350@\002\362@\020USE_MEDIA_PLAYER\200A\001\212A\023CommandProtoMessage'
  _globals['_SUBSCRIBEBLUETOOTHLEADVERTISEMENTSREQUEST']._loaded_options = None
  _globals['_SUBSCRIBEBLUETOOTHLEADVERTISEMENTSREQUEST']._serialized_options = b'\340@B\350@\002\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHSERVICEDATA'].fields_by_name['legacy_data']._loaded_options = None
  _globals['_BLUETOOTHSERVICEDATA'].fields_by_name['legacy_data']._serialized_options = b'\030\001'
  _globals['_BLUETOOTHSERVICEDATA']._loaded_options = None
  _globals['_BLUETOOTHSERVICEDATA']._serialized_options = b'\030\001'
  _globals['_BLUETOOTHLEADVERTISEMENTRESPONSE']._loaded_options = None
  _globals['_BLUETOOTHLEADVERTISEMENTRESPONSE']._serialized_options = b'\030\001\340@C\350@\001\362@\023USE_BLUETOOTH_PROXY\200A\001'
  _globals['_BLUETOOTHLERAWADVERTISEMENT'].fields_by_name['address']._loaded_options = None
  _globals['_BLUETOOTHLERAWADVERTISEMENT'].fields_by_name['address']._serialized_options = b'\200\266\030\001'
  _globals['_BLUETOOTHLERAWADVERTISEMENT'].fields_by_name['rssi']._loaded_options = None
  _globals['_BLUETOOTHLERAWADVERTISEMENT'].fields_by_name['rssi']._serialized_options = b'\200\266\030\001'
  _globals['_BLUETOOTHLERAWADVERTISEMENT'].fields_by_name['data']._loaded_options = None
  _globals['_BLUETOOTHLERAWADVERTISEMENT'].fields_by_name['data']._serialized_options = b'\270\265\030>\200\266\030\001'
  _globals['_BLUETOOTHLERAWADVERTISEMENTSRESPONSE'].fields_by_name['advertisements']._loaded_options = None
  _globals['_BLUETOOTHLERAWADVERTISEMENTSRESPONSE'].fields_by_name['advertisements']._serialized_options = b'\332\265\030(BLUETOOTH_PROXY_ADVERTISEMENT_BATCH_SIZE'
  _globals['_BLUETOOTHLERAWADVERTISEMENTSRESPONSE']._loaded_options = None
  _globals['_BLUETOOTHLERAWADVERTISEMENTSRESPONSE']._serialized_options = b'\340@]\350@\001\362@\023USE_BLUETOOTH_PROXY\200A\001'
  _globals['_BLUETOOTHDEVICEREQUEST']._loaded_options = None
  _globals['_BLUETOOTHDEVICEREQUEST']._serialized_options = b'\340@D\350@\002\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHDEVICECONNECTIONRESPONSE']._loaded_options = None
  _globals['_BLUETOOTHDEVICECONNECTIONRESPONSE']._serialized_options = b'\340@E\350@\001\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHGATTGETSERVICESREQUEST']._loaded_options = None
  _globals['_BLUETOOTHGATTGETSERVICESREQUEST']._serialized_options = b'\340@F\350@\002\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHGATTDESCRIPTOR'].fields_by_name['uuid']._loaded_options = None
  _globals['_BLUETOOTHGATTDESCRIPTOR'].fields_by_name['uuid']._serialized_options = b'\270\265\030\002\310\265\030\001'
  _globals['_BLUETOOTHGATTCHARACTERISTIC'].fields_by_name['uuid']._loaded_options = None
  _globals['_BLUETOOTHGATTCHARACTERISTIC'].fields_by_name['uuid']._serialized_options = b'\270\265\030\002\310\265\030\001'
  _globals['_BLUETOOTHGATTCHARACTERISTIC'].fields_by_name['descriptors']._loaded_options = None
  _globals['_BLUETOOTHGATTCHARACTERISTIC'].fields_by_name['descriptors']._serialized_options = b'\350\265\030\001'
  _globals['_BLUETOOTHGATTSERVICE'].fields_by_name['uuid']._loaded_options = None
  _globals['_BLUETOOTHGATTSERVICE'].fields_by_name['uuid']._serialized_options = b'\270\265\030\002\310\265\030\001'
  _globals['_BLUETOOTHGATTSERVICE'].fields_by_name['characteristics']._loaded_options = None
  _globals['_BLUETOOTHGATTSERVICE'].fields_by_name['characteristics']._serialized_options = b'\350\265\030\001'
  _globals['_BLUETOOTHGATTGETSERVICESRESPONSE']._loaded_options = None
  _globals['_BLUETOOTHGATTGETSERVICESRESPONSE']._serialized_options = b'\340@G\350@\001\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHGATTGETSERVICESDONERESPONSE']._loaded_options = None
  _globals['_BLUETOOTHGATTGETSERVICESDONERESPONSE']._serialized_options = b'\340@H\350@\001\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHGATTREADREQUEST']._loaded_options = None
  _globals['_BLUETOOTHGATTREADREQUEST']._serialized_options = b'\340@I\350@\002\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHGATTREADRESPONSE']._loaded_options = None
  _globals['_BLUETOOTHGATTREADRESPONSE']._serialized_options = b'\340@J\350@\001\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHGATTWRITEREQUEST']._loaded_options = None
  _globals['_BLUETOOTHGATTWRITEREQUEST']._serialized_options = b'\340@K\350@\002\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHGATTREADDESCRIPTORREQUEST']._loaded_options = None
  _globals['_BLUETOOTHGATTREADDESCRIPTORREQUEST']._serialized_options = b'\340@L\350@\002\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHGATTWRITEDESCRIPTORREQUEST']._loaded_options = None
  _globals['_BLUETOOTHGATTWRITEDESCRIPTORREQUEST']._serialized_options = b'\340@M\350@\002\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHGATTNOTIFYREQUEST']._loaded_options = None
  _globals['_BLUETOOTHGATTNOTIFYREQUEST']._serialized_options = b'\340@N\350@\002\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHGATTNOTIFYDATARESPONSE']._loaded_options = None
  _globals['_BLUETOOTHGATTNOTIFYDATARESPONSE']._serialized_options = b'\340@O\350@\001\362@\023USE_BLUETOOTH_PROXY'
  _globals['_SUBSCRIBEBLUETOOTHCONNECTIONSFREEREQUEST']._loaded_options = None
  _globals['_SUBSCRIBEBLUETOOTHCONNECTIONSFREEREQUEST']._serialized_options = b'\340@P\350@\002\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHCONNECTIONSFREERESPONSE'].fields_by_name['allocated']._loaded_options = None
  _globals['_BLUETOOTHCONNECTIONSFREERESPONSE'].fields_by_name['allocated']._serialized_options = b'\310\265\030\001\322\265\030\037BLUETOOTH_PROXY_MAX_CONNECTIONS'
  _globals['_BLUETOOTHCONNECTIONSFREERESPONSE']._loaded_options = None
  _globals['_BLUETOOTHCONNECTIONSFREERESPONSE']._serialized_options = b'\340@Q\350@\001\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHGATTERRORRESPONSE']._loaded_options = None
  _globals['_BLUETOOTHGATTERRORRESPONSE']._serialized_options = b'\340@R\350@\001\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHGATTWRITERESPONSE']._loaded_options = None
  _globals['_BLUETOOTHGATTWRITERESPONSE']._serialized_options = b'\340@S\350@\001\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHGATTNOTIFYRESPONSE']._loaded_options = None
  _globals['_BLUETOOTHGATTNOTIFYRESPONSE']._serialized_options = b'\340@T\350@\001\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHDEVICEPAIRINGRESPONSE']._loaded_options = None
  _globals['_BLUETOOTHDEVICEPAIRINGRESPONSE']._serialized_options = b'\340@U\350@\001\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHDEVICEUNPAIRINGRESPONSE']._loaded_options = None
  _globals['_BLUETOOTHDEVICEUNPAIRINGRESPONSE']._serialized_options = b'\340@V\350@\001\362@\023USE_BLUETOOTH_PROXY'
  _globals['_UNSUBSCRIBEBLUETOOTHLEADVERTISEMENTSREQUEST']._loaded_options = None
  _globals['_UNSUBSCRIBEBLUETOOTHLEADVERTISEMENTSREQUEST']._serialized_options = b'\340@W\350@\002\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHDEVICECLEARCACHERESPONSE']._loaded_options = None
  _globals['_BLUETOOTHDEVICECLEARCACHERESPONSE']._serialized_options = b'\340@X\350@\001\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHSCANNERSTATERESPONSE']._loaded_options = None
  _globals['_BLUETOOTHSCANNERSTATERESPONSE']._serialized_options = b'\340@~\350@\001\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHSCANNERSETMODEREQUEST']._loaded_options = None
  _globals['_BLUETOOTHSCANNERSETMODEREQUEST']._serialized_options = b'\340@\177\350@\002\362@\023USE_BLUETOOTH_PROXY'
  _globals['_SUBSCRIBEVOICEASSISTANTREQUEST']._loaded_options = None
  _globals['_SUBSCRIBEVOICEASSISTANTREQUEST']._serialized_options = b'\340@Y\350@\002\362@\023USE_VOICE_ASSISTANT'
  _globals['_VOICEASSISTANTREQUEST']._loaded_options = None
  _globals['_VOICEASSISTANTREQUEST']._serialized_options = b'\340@Z\350@\001\362@\023USE_VOICE_ASSISTANT'
  _globals['_VOICEASSISTANTRESPONSE']._loaded_options = None
  _globals['_VOICEASSISTANTRESPONSE']._serialized_options = b'\340@[\350@\002\362@\023USE_VOICE_ASSISTANT'
  _globals['_VOICEASSISTANTEVENTRESPONSE']._loaded_options = None
  _globals['_VOICEASSISTANTEVENTRESPONSE']._serialized_options = b'\340@\\\350@\002\362@\023USE_VOICE_ASSISTANT'
  _globals['_VOICEASSISTANTAUDIO'].fields_by_name['data']._loaded_options = None
  _globals['_VOICEASSISTANTAUDIO'].fields_by_name['data']._serialized_options = b'\340\265\030\001'
  _globals['_VOICEASSISTANTAUDIO']._loaded_options = None
  _globals['_VOICEASSISTANTAUDIO']._serialized_options = b'\340@j\350@\000\362@\023USE_VOICE_ASSISTANT'
  _globals['_VOICEASSISTANTTIMEREVENTRESPONSE']._loaded_options = None
  _globals['_VOICEASSISTANTTIMEREVENTRESPONSE']._serialized_options = b'\340@s\350@\002\362@\023USE_VOICE_ASSISTANT'
  _globals['_VOICEASSISTANTANNOUNCEREQUEST']._loaded_options = None
  _globals['_VOICEASSISTANTANNOUNCEREQUEST']._serialized_options = b'\340@w\350@\002\362@\023USE_VOICE_ASSISTANT'
  _globals['_VOICEASSISTANTANNOUNCEFINISHED']._loaded_options = None
  _globals['_VOICEASSISTANTANNOUNCEFINISHED']._serialized_options = b'\340@x\350@\001\362@\023USE_VOICE_ASSISTANT'
  _globals['_VOICEASSISTANTCONFIGURATIONREQUEST']._loaded_options = None
  _globals['_VOICEASSISTANTCONFIGURATIONREQUEST']._serialized_options = b'\340@y\350@\002\362@\023USE_VOICE_ASSISTANT'
  _globals['_VOICEASSISTANTCONFIGURATIONRESPONSE'].fields_by_name['active_wake_words']._loaded_options = None
  _globals['_VOICEASSISTANTCONFIGURATIONRESPONSE'].fields_by_name['active_wake_words']._serialized_options = b'\212\265\030\013std::vector'
  _globals['_VOICEASSISTANTCONFIGURATIONRESPONSE']._loaded_options = None
  _globals['_VOICEASSISTANTCONFIGURATIONRESPONSE']._serialized_options = b'\340@z\350@\001\362@\023USE_VOICE_ASSISTANT'
  _globals['_VOICEASSISTANTSETCONFIGURATION']._loaded_options = None
  _globals['_VOICEASSISTANTSETCONFIGURATION']._serialized_options = b'\340@{\350@\002\362@\023USE_VOICE_ASSISTANT'
  _globals['_LISTENTITIESALARMCONTROLPANELRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESALARMCONTROLPANELRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESALARMCONTROLPANELRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESALARMCONTROLPANELRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESALARMCONTROLPANELRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESALARMCONTROLPANELRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESALARMCONTROLPANELRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESALARMCONTROLPANELRESPONSE']._serialized_options = b'\340@^\350@\001\362@\027USE_ALARM_CONTROL_PANEL\212A\030InfoResponseProtoMessage'
  _globals['_ALARMCONTROLPANELSTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_ALARMCONTROLPANELSTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_ALARMCONTROLPANELSTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_ALARMCONTROLPANELSTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_ALARMCONTROLPANELSTATERESPONSE']._loaded_options = None
  _globals['_ALARMCONTROLPANELSTATERESPONSE']._serialized_options = b'\340@_\350@\001\362@\027USE_ALARM_CONTROL_PANEL\200A\001\212A\031StateResponseProtoMessage'
  _globals['_ALARMCONTROLPANELCOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_ALARMCONTROLPANELCOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_ALARMCONTROLPANELCOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_ALARMCONTROLPANELCOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_ALARMCONTROLPANELCOMMANDREQUEST']._loaded_options = None
  _globals['_ALARMCONTROLPANELCOMMANDREQUEST']._serialized_options = b'\340@`\350@\002\362@\027USE_ALARM_CONTROL_PANEL\200A\001\212A\023CommandProtoMessage'
  _globals['_LISTENTITIESTEXTRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESTEXTRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESTEXTRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESTEXTRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESTEXTRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESTEXTRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESTEXTRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESTEXTRESPONSE']._serialized_options = b'\340@a\350@\001\362@\010USE_TEXT\212A\030InfoResponseProtoMessage'
  _globals['_TEXTSTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_TEXTSTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_TEXTSTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_TEXTSTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_TEXTSTATERESPONSE']._loaded_options = None
  _globals['_TEXTSTATERESPONSE']._serialized_options = b'\340@b\350@\001\362@\010USE_TEXT\200A\001\212A\031StateResponseProtoMessage'
  _globals['_TEXTCOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_TEXTCOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_TEXTCOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_TEXTCOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_TEXTCOMMANDREQUEST']._loaded_options = None
  _globals['_TEXTCOMMANDREQUEST']._serialized_options = b'\340@c\350@\002\362@\010USE_TEXT\200A\001\212A\023CommandProtoMessage'
  _globals['_LISTENTITIESDATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESDATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESDATERESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESDATERESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESDATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESDATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESDATERESPONSE']._loaded_options = None
  _globals['_LISTENTITIESDATERESPONSE']._serialized_options = b'\340@d\350@\001\362@\021USE_DATETIME_DATE\212A\030InfoResponseProtoMessage'
  _globals['_DATESTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_DATESTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_DATESTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_DATESTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_DATESTATERESPONSE']._loaded_options = None
  _globals['_DATESTATERESPONSE']._serialized_options = b'\340@e\350@\001\362@\021USE_DATETIME_DATE\200A\001\212A\031StateResponseProtoMessage'
  _globals['_DATECOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_DATECOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_DATECOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_DATECOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_DATECOMMANDREQUEST']._loaded_options = None
  _globals['_DATECOMMANDREQUEST']._serialized_options = b'\340@f\350@\002\362@\021USE_DATETIME_DATE\200A\001\212A\023CommandProtoMessage'
  _globals['_LISTENTITIESTIMERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESTIMERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESTIMERESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESTIMERESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESTIMERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESTIMERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESTIMERESPONSE']._loaded_options = None
  _globals['_LISTENTITIESTIMERESPONSE']._serialized_options = b'\340@g\350@\001\362@\021USE_DATETIME_TIME\212A\030InfoResponseProtoMessage'
  _globals['_TIMESTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_TIMESTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_TIMESTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_TIMESTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_TIMESTATERESPONSE']._loaded_options = None
  _globals['_TIMESTATERESPONSE']._serialized_options = b'\340@h\350@\001\362@\021USE_DATETIME_TIME\200A\001\212A\031StateResponseProtoMessage'
  _globals['_TIMECOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_TIMECOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_TIMECOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_TIMECOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_TIMECOMMANDREQUEST']._loaded_options = None
  _globals['_TIMECOMMANDREQUEST']._serialized_options = b'\340@i\350@\002\362@\021USE_DATETIME_TIME\200A\001\212A\023CommandProtoMessage'
  _globals['_LISTENTITIESEVENTRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESEVENTRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESEVENTRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESEVENTRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESEVENTRESPONSE'].fields_by_name['event_types']._loaded_options = None
  _globals['_LISTENTITIESEVENTRESPONSE'].fields_by_name['event_types']._serialized_options = b'\362\265\030\031FixedVector<const char *>'
  _globals['_LISTENTITIESEVENTRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESEVENTRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESEVENTRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESEVENTRESPONSE']._serialized_options = b'\340@k\350@\001\362@\tUSE_EVENT\212A\030InfoResponseProtoMessage'
  _globals['_EVENTRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_EVENTRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_EVENTRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_EVENTRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_EVENTRESPONSE']._loaded_options = None
  _globals['_EVENTRESPONSE']._serialized_options = b'\340@l\350@\001\362@\tUSE_EVENT\212A\031StateResponseProtoMessage'
  _globals['_LISTENTITIESVALVERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESVALVERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESVALVERESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESVALVERESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESVALVERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESVALVERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESVALVERESPONSE']._loaded_options = None
  _globals['_LISTENTITIESVALVERESPONSE']._serialized_options = b'\340@m\350@\001\362@\tUSE_VALVE\212A\030InfoResponseProtoMessage'
  _globals['_VALVESTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_VALVESTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_VALVESTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_VALVESTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_VALVESTATERESPONSE']._loaded_options = None
  _globals['_VALVESTATERESPONSE']._serialized_options = b'\340@n\350@\001\362@\tUSE_VALVE\200A\001\212A\031StateResponseProtoMessage'
  _globals['_VALVECOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_VALVECOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_VALVECOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_VALVECOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_VALVECOMMANDREQUEST']._loaded_options = None
  _globals['_VALVECOMMANDREQUEST']._serialized_options = b'\340@o\350@\002\362@\tUSE_VALVE\200A\001\212A\023CommandProtoMessage'
  _globals['_LISTENTITIESDATETIMERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESDATETIMERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESDATETIMERESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESDATETIMERESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESDATETIMERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESDATETIMERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESDATETIMERESPONSE']._loaded_options = None
  _globals['_LISTENTITIESDATETIMERESPONSE']._serialized_options = b'\340@p\350@\001\362@\025USE_DATETIME_DATETIME\212A\030InfoResponseProtoMessage'
  _globals['_DATETIMESTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_DATETIMESTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_DATETIMESTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_DATETIMESTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_DATETIMESTATERESPONSE']._loaded_options = None
  _globals['_DATETIMESTATERESPONSE']._serialized_options = b'\340@q\350@\001\362@\025USE_DATETIME_DATETIME\200A\001\212A\031StateResponseProtoMessage'
  _globals['_DATETIMECOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_DATETIMECOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_DATETIMECOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_DATETIMECOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_DATETIMECOMMANDREQUEST']._loaded_options = None
  _globals['_DATETIMECOMMANDREQUEST']._serialized_options = b'\340@r\350@\002\362@\025USE_DATETIME_DATETIME\200A\001\212A\023CommandProtoMessage'
  _globals['_LISTENTITIESUPDATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESUPDATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESUPDATERESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESUPDATERESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESUPDATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESUPDATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESUPDATERESPONSE']._loaded_options = None
  _globals['_LISTENTITIESUPDATERESPONSE']._serialized_options = b'\340@t\350@\001\362@\nUSE_UPDATE\212A\030InfoResponseProtoMessage'
  _globals['_UPDATESTATERESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_UPDATESTATERESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_UPDATESTATERESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_UPDATESTATERESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_UPDATESTATERESPONSE']._loaded_options = None
  _globals['_UPDATESTATERESPONSE']._serialized_options = b'\340@u\350@\001\362@\nUSE_UPDATE\200A\001\212A\031StateResponseProtoMessage'
  _globals['_UPDATECOMMANDREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_UPDATECOMMANDREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_UPDATECOMMANDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_UPDATECOMMANDREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_UPDATECOMMANDREQUEST']._loaded_options = None
  _globals['_UPDATECOMMANDREQUEST']._serialized_options = b'\340@v\350@\002\362@\nUSE_UPDATE\200A\001\212A\023CommandProtoMessage'
  _globals['_ZWAVEPROXYFRAME']._loaded_options = None
  _globals['_ZWAVEPROXYFRAME']._serialized_options = b'\340@\200\001\350@\000\362@\017USE_ZWAVE_PROXY\200A\001'
  _globals['_ZWAVEPROXYREQUEST']._loaded_options = None
  _globals['_ZWAVEPROXYREQUEST']._serialized_options = b'\340@\201\001\350@\000\362@\017USE_ZWAVE_PROXY'
  _globals['_LISTENTITIESINFRAREDRESPONSE'].fields_by_name['key']._loaded_options = None
  _globals['_LISTENTITIESINFRAREDRESPONSE'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_LISTENTITIESINFRAREDRESPONSE'].fields_by_name['icon']._loaded_options = None
  _globals['_LISTENTITIESINFRAREDRESPONSE'].fields_by_name['icon']._serialized_options = b'\222A\017USE_ENTITY_ICON'
  _globals['_LISTENTITIESINFRAREDRESPONSE'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTENTITIESINFRAREDRESPONSE'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_LISTENTITIESINFRAREDRESPONSE']._loaded_options = None
  _globals['_LISTENTITIESINFRAREDRESPONSE']._serialized_options = b'\340@\207\001\350@\001\362@\014USE_INFRARED\212A\030InfoResponseProtoMessage'
  _globals['_INFRAREDRFTRANSMITRAWTIMINGSREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_INFRAREDRFTRANSMITRAWTIMINGSREQUEST'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_INFRAREDRFTRANSMITRAWTIMINGSREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_INFRAREDRFTRANSMITRAWTIMINGSREQUEST'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_INFRAREDRFTRANSMITRAWTIMINGSREQUEST'].fields_by_name['timings']._loaded_options = None
  _globals['_INFRAREDRFTRANSMITRAWTIMINGSREQUEST'].fields_by_name['timings']._serialized_options = b'\020\001\370\265\030\001'
  _globals['_INFRAREDRFTRANSMITRAWTIMINGSREQUEST']._loaded_options = None
  _globals['_INFRAREDRFTRANSMITRAWTIMINGSREQUEST']._serialized_options = b'\340@\210\001\350@\002\362@\tUSE_IR_RF'
  _globals['_INFRAREDRFRECEIVEEVENT'].fields_by_name['device_id']._loaded_options = None
  _globals['_INFRAREDRFRECEIVEEVENT'].fields_by_name['device_id']._serialized_options = b'\222A\013USE_DEVICES'
  _globals['_INFRAREDRFRECEIVEEVENT'].fields_by_name['key']._loaded_options = None
  _globals['_INFRAREDRFRECEIVEEVENT'].fields_by_name['key']._serialized_options = b'\200\266\030\001'
  _globals['_INFRAREDRFRECEIVEEVENT'].fields_by_name['timings']._loaded_options = None
  _globals['_INFRAREDRFRECEIVEEVENT'].fields_by_name['timings']._serialized_options = b'\020\001\362\265\030\024std::vector<int32_t>'
  _globals['_INFRAREDRFRECEIVEEVENT']._loaded_options = None
  _globals['_INFRAREDRFRECEIVEEVENT']._serialized_options = b'\340@\211\001\350@\001\362@\tUSE_IR_RF\200A\001'
  _globals['_SERIALPROXYCONFIGUREREQUEST']._loaded_options = None
  _globals['_SERIALPROXYCONFIGUREREQUEST']._serialized_options = b'\340@\212\001\350@\002\362@\020USE_SERIAL_PROXY'
  _globals['_SERIALPROXYDATARECEIVED']._loaded_options = None
  _globals['_SERIALPROXYDATARECEIVED']._serialized_options = b'\340@\213\001\350@\001\362@\020USE_SERIAL_PROXY\200A\001'
  _globals['_SERIALPROXYWRITEREQUEST']._loaded_options = None
  _globals['_SERIALPROXYWRITEREQUEST']._serialized_options = b'\340@\214\001\350@\002\362@\020USE_SERIAL_PROXY\200A\001'
  _globals['_SERIALPROXYSETMODEMPINSREQUEST']._loaded_options = None
  _globals['_SERIALPROXYSETMODEMPINSREQUEST']._serialized_options = b'\340@\215\001\350@\002\362@\020USE_SERIAL_PROXY'
  _globals['_SERIALPROXYGETMODEMPINSREQUEST']._loaded_options = None
  _globals['_SERIALPROXYGETMODEMPINSREQUEST']._serialized_options = b'\340@\216\001\350@\002\362@\020USE_SERIAL_PROXY'
  _globals['_SERIALPROXYGETMODEMPINSRESPONSE']._loaded_options = None
  _globals['_SERIALPROXYGETMODEMPINSRESPONSE']._serialized_options = b'\340@\217\001\350@\001\362@\020USE_SERIAL_PROXY'
  _globals['_SERIALPROXYREQUEST']._loaded_options = None
  _globals['_SERIALPROXYREQUEST']._serialized_options = b'\340@\220\001\350@\002\362@\020USE_SERIAL_PROXY'
  _globals['_SERIALPROXYREQUESTRESPONSE']._loaded_options = None
  _globals['_SERIALPROXYREQUESTRESPONSE']._serialized_options = b'\340@\223\001\350@\001\362@\020USE_SERIAL_PROXY'
  _globals['_BLUETOOTHSETCONNECTIONPARAMSREQUEST']._loaded_options = None
  _globals['_BLUETOOTHSETCONNECTIONPARAMSREQUEST']._serialized_options = b'\340@\221\001\350@\002\362@\023USE_BLUETOOTH_PROXY'
  _globals['_BLUETOOTHSETCONNECTIONPARAMSRESPONSE']._loaded_options = None
  _globals['_BLUETOOTHSETCONNECTIONPARAMSRESPONSE']._serialized_options = b'\340@\222\001\350@\001\362@\023USE_BLUETOOTH_PROXY'
  _globals['_APICONNECTION'].methods_by_name['hello']._loaded_options = None
  _globals['_APICONNECTION'].methods_by_name['hello']._serialized_options = b'\360@\000\370@\000'
  _globals['_APICONNECTION'].methods_by_name['disconnect']._loaded_options = None
  _globals['_APICONNECTION'].methods_by_name['disconnect']._serialized_options = b'\360@\000\370@\000'
  _globals['_APICONNECTION'].methods_by_name['ping']._loaded_options = None
  _globals['_APICONNECTION'].methods_by_name['ping']._serialized_options = b'\360@\000\370@\000'
  _globals['_APICONNECTION'].methods_by_name['device_info']._loaded_options = None
  _globals['_APICONNECTION'].methods_by_name['device_info']._serialized_options = b'\370@\000'
  _globals['_SERIALPROXYPORTTYPE']._serialized_start=32224
  _globals['_SERIALPROXYPORTTYPE']._serialized_end=32345
  _globals['_ENTITYCATEGORY']._serialized_start=32347
  _globals['_ENTITYCATEGORY']._serialized_end=32449
  _globals['_LEGACYCOVERSTATE']._serialized_start=32451
  _globals['_LEGACYCOVERSTATE']._serialized_end=32533
  _globals['_COVEROPERATION']._serialized_start=32535
  _globals['_COVEROPERATION']._serialized_end=32641
  _globals['_LEGACYCOVERCOMMAND']._serialized_start=32643
  _globals['_LEGACYCOVERCOMMAND']._serialized_end=32761
  _globals['_FANSPEED']._serialized_start=32763
  _globals['_FANSPEED']._serialized_end=32838
  _globals['_FANDIRECTION']._serialized_start=32840
  _globals['_FANDIRECTION']._serialized_end=32908
  _globals['_COLORMODE']._serialized_start=32911
  _globals['_COLORMODE']._serialized_end=33238
  _globals['_SENSORSTATECLASS']._serialized_start=33241
  _globals['_SENSORSTATECLASS']._serialized_end=33402
  _globals['_SENSORLASTRESETTYPE']._serialized_start=33404
  _globals['_SENSORLASTRESETTYPE']._serialized_end=33493
  _globals['_LOGLEVEL']._serialized_start=33496
  _globals['_LOGLEVEL']._serialized_end=33681
  _globals['_DSTRULETYPE']._serialized_start=33684
  _globals['_DSTRULETYPE']._serialized_end=33820
  _globals['_SERVICEARGTYPE']._serialized_start=33823
  _globals['_SERVICEARGTYPE']._serialized_end=34083
  _globals['_SUPPORTSRESPONSETYPE']._serialized_start=34086
  _globals['_SUPPORTSRESPONSETYPE']._serialized_end=34226
  _globals['_CLIMATEMODE']._serialized_start=34229
  _globals['_CLIMATEMODE']._serialized_end=34410
  _globals['_CLIMATEFANMODE']._serialized_start=34413
  _globals['_CLIMATEFANMODE']._serialized_end=34654
  _globals['_CLIMATESWINGMODE']._serialized_start=34656
  _globals['_CLIMATESWINGMODE']._serialized_end=34779
  _globals['_CLIMATEACTION']._serialized_start=34782
  _globals['_CLIMATEACTION']._serialized_end=34984
  _globals['_CLIMATEPRESET']._serialized_start=34987
  _globals['_CLIMATEPRESET']._serialized_end=35210
  _globals['_WATERHEATERMODE']._serialized_start=35213
  _globals['_WATERHEATERMODE']._serialized_end=35446
  _globals['_WATERHEATERCOMMANDHASFIELD']._serialized_start=35449
  _globals['_WATERHEATERCOMMANDHASFIELD']._serialized_end=35823
  _globals['_NUMBERMODE']._serialized_start=35825
  _globals['_NUMBERMODE']._serialized_end=35904
  _globals['_LOCKSTATE']._serialized_start=35907
  _globals['_LOCKSTATE']._serialized_end=36060
  _globals['_LOCKCOMMAND']._serialized_start=36062
  _globals['_LOCKCOMMAND']._serialized_end=36122
  _globals['_MEDIAPLAYERSTATE']._serialized_start=36125
  _globals['_MEDIAPLAYERSTATE']._serialized_end=36354
  _globals['_MEDIAPLAYERCOMMAND']._serialized_start=36357
  _globals['_MEDIAPLAYERCOMMAND']._serialized_end=36860
  _globals['_MEDIAPLAYERFORMATPURPOSE']._serialized_start=36862
  _globals['_MEDIAPLAYERFORMATPURPOSE']._serialized_end=36975
  _globals['_BLUETOOTHDEVICEREQUESTTYPE']._serialized_start=36978
  _globals['_BLUETOOTHDEVICEREQUESTTYPE']._serialized_end=37345
  _globals['_BLUETOOTHSCANNERSTATE']._serialized_start=37348
  _globals['_BLUETOOTHSCANNERSTATE']._serialized_end=37591
  _globals['_BLUETOOTHSCANNERMODE']._serialized_start=37593
  _globals['_BLUETOOTHSCANNERMODE']._serialized_end=37686
  _globals['_VOICEASSISTANTSUBSCRIBEFLAG']._serialized_start=37688
  _globals['_VOICEASSISTANTSUBSCRIBEFLAG']._serialized_end=37794
  _globals['_VOICEASSISTANTREQUESTFLAG']._serialized_start=37797
  _globals['_VOICEASSISTANTREQUESTFLAG']._serialized_end=37938
  _globals['_VOICEASSISTANTEVENT']._serialized_start=37941
  _globals['_VOICEASSISTANTEVENT']._serialized_end=38486
  _globals['_VOICEASSISTANTTIMEREVENT']._serialized_start=38489
  _globals['_VOICEASSISTANTTIMEREVENT']._serialized_end=38658
  _globals['_ALARMCONTROLPANELSTATE']._serialized_start=38661
  _globals['_ALARMCONTROLPANELSTATE']._serialized_end=38968
  _globals['_ALARMCONTROLPANELSTATECOMMAND']._serialized_start=38971
  _globals['_ALARMCONTROLPANELSTATECOMMAND']._serialized_end=39251
  _globals['_TEXTMODE']._serialized_start=39253
  _globals['_TEXTMODE']._serialized_end=39307
  _globals['_VALVEOPERATION']._serialized_start=39309
  _globals['_VALVEOPERATION']._serialized_end=39415
  _globals['_UPDATECOMMAND']._serialized_start=39417
  _globals['_UPDATECOMMAND']._serialized_end=39510
  _globals['_ZWAVEPROXYREQUESTTYPE']._serialized_start=39513
  _globals['_ZWAVEPROXYREQUESTTYPE']._serialized_end=39663
  _globals['_SERIALPROXYPARITY']._serialized_start=39665
  _globals['_SERIALPROXYPARITY']._serialized_end=39773
  _globals['_SERIALPROXYREQUESTTYPE']._serialized_start=39776
  _globals['_SERIALPROXYREQUESTTYPE']._serialized_end=39921
  _globals['_SERIALPROXYSTATUS']._serialized_start=39924
  _globals['_SERIALPROXYSTATUS']._serialized_end=40115
  _globals['_HELLOREQUEST']._serialized_start=32
  _globals['_HELLOREQUEST']._serialized_end=132
  _globals['_HELLORESPONSE']._serialized_start=134
  _globals['_HELLORESPONSE']._serialized_end=249
  _globals['_AUTHENTICATIONREQUEST']._serialized_start=251
  _globals['_AUTHENTICATIONREQUEST']._serialized_end=305
  _globals['_AUTHENTICATIONRESPONSE']._serialized_start=307
  _globals['_AUTHENTICATIONRESPONSE']._serialized_end=370
  _globals['_DISCONNECTREQUEST']._serialized_start=372
  _globals['_DISCONNECTREQUEST']._serialized_end=402
  _globals['_DISCONNECTRESPONSE']._serialized_start=404
  _globals['_DISCONNECTRESPONSE']._serialized_end=435
  _globals['_PINGREQUEST']._serialized_start=437
  _globals['_PINGREQUEST']._serialized_end=458
  _globals['_PINGRESPONSE']._serialized_start=460
  _globals['_PINGRESPONSE']._serialized_end=482
  _globals['_DEVICEINFOREQUEST']._serialized_start=484
  _globals['_DEVICEINFOREQUEST']._serialized_end=511
  _globals['_AREAINFO']._serialized_start=513
  _globals['_AREAINFO']._serialized_end=554
  _globals['_DEVICEINFO']._serialized_start=556
  _globals['_DEVICEINFO']._serialized_end=618
  _globals['_SERIALPROXYINFO']._serialized_start=620
  _globals['_SERIALPROXYINFO']._serialized_end=692
  _globals['_DEVICEINFORESPONSE']._serialized_start=695
  _globals['_DEVICEINFORESPONSE']._serialized_end=1835
  _globals['_LISTENTITIESREQUEST']._serialized_start=1837
  _globals['_LISTENTITIESREQUEST']._serialized_end=1866
  _globals['_LISTENTITIESDONERESPONSE']._serialized_start=1868
  _globals['_LISTENTITIESDONERESPONSE']._serialized_end=1905
  _globals['_SUBSCRIBESTATESREQUEST']._serialized_start=1907
  _globals['_SUBSCRIBESTATESREQUEST']._serialized_end=1939
  _globals['_LISTENTITIESBINARYSENSORRESPONSE']._serialized_start=1942
  _globals['_LISTENTITIESBINARYSENSORRESPONSE']._serialized_end=2284
  _globals['_BINARYSENSORSTATERESPONSE']._serialized_start=2287
  _globals['_BINARYSENSORSTATERESPONSE']._serialized_end=2465
  _globals['_LISTENTITIESCOVERRESPONSE']._serialized_start=2468
  _globals['_LISTENTITIESCOVERRESPONSE']._serialized_end=2858
  _globals['_COVERSTATERESPONSE']._serialized_start=2861
  _globals['_COVERSTATERESPONSE']._serialized_end=3107
  _globals['_COVERCOMMANDREQUEST']._serialized_start=3110
  _globals['_COVERCOMMANDREQUEST']._serialized_end=3397
  _globals['_LISTENTITIESFANRESPONSE']._serialized_start=3400
  _globals['_LISTENTITIESFANRESPONSE']._serialized_end=3844
  _globals['_FANSTATERESPONSE']._serialized_start=3847
  _globals['_FANSTATERESPONSE']._serialized_end=4110
  _globals['_FANCOMMANDREQUEST']._serialized_start=4113
  _globals['_FANCOMMANDREQUEST']._serialized_end=4511
  _globals['_LISTENTITIESLIGHTRESPONSE']._serialized_start=4514
  _globals['_LISTENTITIESLIGHTRESPONSE']._serialized_end=5104
  _globals['_LIGHTSTATERESPONSE']._serialized_start=5107
  _globals['_LIGHTSTATERESPONSE']._serialized_end=5465
  _globals['_LIGHTCOMMANDREQUEST']._serialized_start=5468
  _globals['_LIGHTCOMMANDREQUEST']._serialized_end=6159
  _globals['_LISTENTITIESSENSORRESPONSE']._serialized_start=6162
  _globals['_LISTENTITIESSENSORRESPONSE']._serialized_end=6634
  _globals['_SENSORSTATERESPONSE']._serialized_start=6637
  _globals['_SENSORSTATERESPONSE']._serialized_end=6802
  _globals['_LISTENTITIESSWITCHRESPONSE']._serialized_start=6805
  _globals['_LISTENTITIESSWITCHRESPONSE']._serialized_end=7124
  _globals['_SWITCHSTATERESPONSE']._serialized_start=7127
  _globals['_SWITCHSTATERESPONSE']._serialized_end=7269
  _globals['_SWITCHCOMMANDREQUEST']._serialized_start=7272
  _globals['_SWITCHCOMMANDREQUEST']._serialized_end=7409
  _globals['_LISTENTITIESTEXTSENSORRESPONSE']._serialized_start=7412
  _globals['_LISTENTITIESTEXTSENSORRESPONSE']._serialized_end=7717
  _globals['_TEXTSENSORSTATERESPONSE']._serialized_start=7720
  _globals['_TEXTSENSORSTATERESPONSE']._serialized_end=7894
  _globals['_SUBSCRIBELOGSREQUEST']._serialized_start=7896
  _globals['_SUBSCRIBELOGSREQUEST']._serialized_end=7973
  _globals['_SUBSCRIBELOGSRESPONSE']._serialized_start=7975
  _globals['_SUBSCRIBELOGSRESPONSE']._serialized_end=8055
  _globals['_NOISEENCRYPTIONSETKEYREQUEST']._serialized_start=8057
  _globals['_NOISEENCRYPTIONSETKEYREQUEST']._serialized_end=8124
  _globals['_NOISEENCRYPTIONSETKEYRESPONSE']._serialized_start=8126
  _globals['_NOISEENCRYPTIONSETKEYRESPONSE']._serialized_end=8198
  _globals['_SUBSCRIBEHOMEASSISTANTSERVICESREQUEST']._serialized_start=8200
  _globals['_SUBSCRIBEHOMEASSISTANTSERVICESREQUEST']._serialized_end=8280
  _globals['_HOMEASSISTANTSERVICEMAP']._serialized_start=8282
  _globals['_HOMEASSISTANTSERVICEMAP']._serialized_end=8335
  _globals['_HOMEASSISTANTACTIONREQUEST']._serialized_start=8338
  _globals['_HOMEASSISTANTACTIONREQUEST']._serialized_end=8804
  _globals['_HOMEASSISTANTACTIONRESPONSE']._serialized_start=8807
  _globals['_HOMEASSISTANTACTIONRESPONSE']._serialized_end=9017
  _globals['_SUBSCRIBEHOMEASSISTANTSTATESREQUEST']._serialized_start=9019
  _globals['_SUBSCRIBEHOMEASSISTANTSTATESREQUEST']._serialized_end=9095
  _globals['_SUBSCRIBEHOMEASSISTANTSTATERESPONSE']._serialized_start=9098
  _globals['_SUBSCRIBEHOMEASSISTANTSTATERESPONSE']._serialized_end=9226
  _globals['_HOMEASSISTANTSTATERESPONSE']._serialized_start=9228
  _globals['_HOMEASSISTANTSTATERESPONSE']._serialized_end=9351
  _globals['_GETTIMEREQUEST']._serialized_start=9353
  _globals['_GETTIMEREQUEST']._serialized_end=9377
  _globals['_DSTRULE']._serialized_start=9379
  _globals['_DSTRULE']._serialized_end=9506
  _globals['_PARSEDTIMEZONE']._serialized_start=9509
  _globals['_PARSEDTIMEZONE']._serialized_end=9642
  _globals['_GETTIMERESPONSE']._serialized_start=9644
  _globals['_GETTIMERESPONSE']._serialized_end=9755
  _globals['_LISTENTITIESSERVICESARGUMENT']._serialized_start=9757
  _globals['_LISTENTITIESSERVICESARGUMENT']._serialized_end=9865
  _globals['_LISTENTITIESSERVICESRESPONSE']._serialized_start=9868
  _globals['_LISTENTITIESSERVICESRESPONSE']._serialized_end=10071
  _globals['_EXECUTESERVICEARGUMENT']._serialized_start=10074
  _globals['_EXECUTESERVICEARGUMENT']._serialized_end=10325
  _globals['_EXECUTESERVICEREQUEST']._serialized_start=10328
  _globals['_EXECUTESERVICEREQUEST']._serialized_end=10583
  _globals['_EXECUTESERVICERESPONSE']._serialized_start=10586
  _globals['_EXECUTESERVICERESPONSE']._serialized_end=10793
  _globals['_LISTENTITIESCAMERARESPONSE']._serialized_start=10796
  _globals['_LISTENTITIESCAMERARESPONSE']._serialized_end=11070
  _globals['_CAMERAIMAGERESPONSE']._serialized_start=11073
  _globals['_CAMERAIMAGERESPONSE']._serialized_end=11225
  _globals['_CAMERAIMAGEREQUEST']._serialized_start=11227
  _globals['_CAMERAIMAGEREQUEST']._serialized_end=11303
  _globals['_LISTENTITIESCLIMATERESPONSE']._serialized_start=11306
  _globals['_LISTENTITIESCLIMATERESPONSE']._serialized_end=12461
  _globals['_CLIMATESTATERESPONSE']._serialized_start=12464
  _globals['_CLIMATESTATERESPONSE']._serialized_end=13012
  _globals['_CLIMATECOMMANDREQUEST']._serialized_start=13015
  _globals['_CLIMATECOMMANDREQUEST']._serialized_end=13781
  _globals['_LISTENTITIESWATERHEATERRESPONSE']._serialized_start=13784
  _globals['_LISTENTITIESWATERHEATERRESPONSE']._serialized_end=14257
  _globals['_WATERHEATERSTATERESPONSE']._serialized_start=14260
  _globals['_WATERHEATERSTATERESPONSE']._serialized_end=14568
  _globals['_WATERHEATERCOMMANDREQUEST']._serialized_start=14571
  _globals['_WATERHEATERCOMMANDREQUEST']._serialized_end=14865
  _globals['_LISTENTITIESNUMBERRESPONSE']._serialized_start=14868
  _globals['_LISTENTITIESNUMBERRESPONSE']._serialized_end=15272
  _globals['_NUMBERSTATERESPONSE']._serialized_start=15275
  _globals['_NUMBERSTATERESPONSE']._serialized_end=15440
  _globals['_NUMBERCOMMANDREQUEST']._serialized_start=15443
  _globals['_NUMBERCOMMANDREQUEST']._serialized_end=15580
  _globals['_LISTENTITIESSELECTRESPONSE']._serialized_start=15583
  _globals['_LISTENTITIESSELECTRESPONSE']._serialized_end=15905
  _globals['_SELECTSTATERESPONSE']._serialized_start=15908
  _globals['_SELECTSTATERESPONSE']._serialized_end=16073
  _globals['_SELECTCOMMANDREQUEST']._serialized_start=16076
  _globals['_SELECTCOMMANDREQUEST']._serialized_end=16213
  _globals['_LISTENTITIESSIRENRESPONSE']._serialized_start=16216
  _globals['_LISTENTITIESSIRENRESPONSE']._serialized_end=16586
  _globals['_SIRENSTATERESPONSE']._serialized_start=16589
  _globals['_SIRENSTATERESPONSE']._serialized_end=16729
  _globals['_SIRENCOMMANDREQUEST']._serialized_start=16732
  _globals['_SIRENCOMMANDREQUEST']._serialized_end=16994
  _globals['_LISTENTITIESLOCKRESPONSE']._serialized_start=16997
  _globals['_LISTENTITIESLOCKRESPONSE']._serialized_end=17357
  _globals['_LOCKSTATERESPONSE']._serialized_start=17360
  _globals['_LOCKSTATERESPONSE']._serialized_end=17510
  _globals['_LOCKCOMMANDREQUEST']._serialized_start=17513
  _globals['_LOCKCOMMANDREQUEST']._serialized_end=17694
  _globals['_LISTENTITIESBUTTONRESPONSE']._serialized_start=17697
  _globals['_LISTENTITIESBUTTONRESPONSE']._serialized_end=17993
  _globals['_BUTTONCOMMANDREQUEST']._serialized_start=17995
  _globals['_BUTTONCOMMANDREQUEST']._serialized_end=18117
  _globals['_MEDIAPLAYERSUPPORTEDFORMAT']._serialized_start=18120
  _globals['_MEDIAPLAYERSUPPORTEDFORMAT']._serialized_end=18294
  _globals['_LISTENTITIESMEDIAPLAYERRESPONSE']._serialized_start=18297
  _globals['_LISTENTITIESMEDIAPLAYERRESPONSE']._serialized_end=18685
  _globals['_MEDIAPLAYERSTATERESPONSE']._serialized_start=18688
  _globals['_MEDIAPLAYERSTATERESPONSE']._serialized_end=18891
  _globals['_MEDIAPLAYERCOMMANDREQUEST']._serialized_start=18894
  _globals['_MEDIAPLAYERCOMMANDREQUEST']._serialized_end=19212
  _globals['_SUBSCRIBEBLUETOOTHLEADVERTISEMENTSREQUEST']._serialized_start=19214
  _globals['_SUBSCRIBEBLUETOOTHLEADVERTISEMENTSREQUEST']._serialized_end=19302
  _globals['_BLUETOOTHSERVICEDATA']._serialized_start=19304
  _globals['_BLUETOOTHSERVICEDATA']._serialized_end=19383
  _globals['_BLUETOOTHLEADVERTISEMENTRESPONSE']._serialized_start=19386
  _globals['_BLUETOOTHLEADVERTISEMENTRESPONSE']._serialized_end=19640
  _globals['_BLUETOOTHLERAWADVERTISEMENT']._serialized_start=19642
  _globals['_BLUETOOTHLERAWADVERTISEMENT']._serialized_end=19760
  _globals['_BLUETOOTHLERAWADVERTISEMENTSRESPONSE']._serialized_start=19763
  _globals['_BLUETOOTHLERAWADVERTISEMENTSRESPONSE']._serialized_end=19934
  _globals['_BLUETOOTHDEVICEREQUEST']._serialized_start=19937
  _globals['_BLUETOOTHDEVICEREQUEST']._serialized_end=20107
  _globals['_BLUETOOTHDEVICECONNECTIONRESPONSE']._serialized_start=20110
  _globals['_BLUETOOTHDEVICECONNECTIONRESPONSE']._serialized_end=20239
  _globals['_BLUETOOTHGATTGETSERVICESREQUEST']._serialized_start=20241
  _globals['_BLUETOOTHGATTGETSERVICESREQUEST']._serialized_end=20321
  _globals['_BLUETOOTHGATTDESCRIPTOR']._serialized_start=20323
  _globals['_BLUETOOTHGATTDESCRIPTOR']._serialized_end=20408
  _globals['_BLUETOOTHGATTCHARACTERISTIC']._serialized_start=20411
  _globals['_BLUETOOTHGATTCHARACTERISTIC']._serialized_end=20573
  _globals['_BLUETOOTHGATTSERVICE']._serialized_start=20576
  _globals['_BLUETOOTHGATTSERVICE']._serialized_end=20719
  _globals['_BLUETOOTHGATTGETSERVICESRESPONSE']._serialized_start=20721
  _globals['_BLUETOOTHGATTGETSERVICESRESPONSE']._serialized_end=20843
  _globals['_BLUETOOTHGATTGETSERVICESDONERESPONSE']._serialized_start=20845
  _globals['_BLUETOOTHGATTGETSERVICESDONERESPONSE']._serialized_end=20930
  _globals['_BLUETOOTHGATTREADREQUEST']._serialized_start=20932
  _globals['_BLUETOOTHGATTREADREQUEST']._serialized_end=21021
  _globals['_BLUETOOTHGATTREADRESPONSE']._serialized_start=21023
  _globals['_BLUETOOTHGATTREADRESPONSE']._serialized_end=21127
  _globals['_BLUETOOTHGATTWRITEREQUEST']._serialized_start=21129
  _globals['_BLUETOOTHGATTWRITEREQUEST']._serialized_end=21251
  _globals['_BLUETOOTHGATTREADDESCRIPTORREQUEST']._serialized_start=21253
  _globals['_BLUETOOTHGATTREADDESCRIPTORREQUEST']._serialized_end=21352
  _globals['_BLUETOOTHGATTWRITEDESCRIPTORREQUEST']._serialized_start=21354
  _globals['_BLUETOOTHGATTWRITEDESCRIPTORREQUEST']._serialized_end=21468
  _globals['_BLUETOOTHGATTNOTIFYREQUEST']._serialized_start=21470
  _globals['_BLUETOOTHGATTNOTIFYREQUEST']._serialized_end=21577
  _globals['_BLUETOOTHGATTNOTIFYDATARESPONSE']._serialized_start=21579
  _globals['_BLUETOOTHGATTNOTIFYDATARESPONSE']._serialized_end=21689
  _globals['_SUBSCRIBEBLUETOOTHCONNECTIONSFREEREQUEST']._serialized_start=21691
  _globals['_SUBSCRIBEBLUETOOTHCONNECTIONSFREEREQUEST']._serialized_end=21763
  _globals['_BLUETOOTHCONNECTIONSFREERESPONSE']._serialized_start=21766
  _globals['_BLUETOOTHCONNECTIONSFREERESPONSE']._serialized_end=21919
  _globals['_BLUETOOTHGATTERRORRESPONSE']._serialized_start=21921
  _globals['_BLUETOOTHGATTERRORRESPONSE']._serialized_end=22027
  _globals['_BLUETOOTHGATTWRITERESPONSE']._serialized_start=22029
  _globals['_BLUETOOTHGATTWRITERESPONSE']._serialized_end=22120
  _globals['_BLUETOOTHGATTNOTIFYRESPONSE']._serialized_start=22122
  _globals['_BLUETOOTHGATTNOTIFYRESPONSE']._serialized_end=22214
  _globals['_BLUETOOTHDEVICEPAIRINGRESPONSE']._serialized_start=22216
  _globals['_BLUETOOTHDEVICEPAIRINGRESPONSE']._serialized_end=22326
  _globals['_BLUETOOTHDEVICEUNPAIRINGRESPONSE']._serialized_start=22328
  _globals['_BLUETOOTHDEVICEUNPAIRINGRESPONSE']._serialized_end=22441
  _globals['_UNSUBSCRIBEBLUETOOTHLEADVERTISEMENTSREQUEST']._serialized_start=22443
  _globals['_UNSUBSCRIBEBLUETOOTHLEADVERTISEMENTSREQUEST']._serialized_end=22518
  _globals['_BLUETOOTHDEVICECLEARCACHERESPONSE']._serialized_start=22520
  _globals['_BLUETOOTHDEVICECLEARCACHERESPONSE']._serialized_end=22634
  _globals['_BLUETOOTHSCANNERSTATERESPONSE']._serialized_start=22637
  _globals['_BLUETOOTHSCANNERSTATERESPONSE']._serialized_end=22822
  _globals['_BLUETOOTHSCANNERSETMODEREQUEST']._serialized_start=22824
  _globals['_BLUETOOTHSCANNERSETMODEREQUEST']._serialized_end=22923
  _globals['_SUBSCRIBEVOICEASSISTANTREQUEST']._serialized_start=22925
  _globals['_SUBSCRIBEVOICEASSISTANTREQUEST']._serialized_end=23021
  _globals['_VOICEASSISTANTAUDIOSETTINGS']._serialized_start=23023
  _globals['_VOICEASSISTANTAUDIOSETTINGS']._serialized_end=23131
  _globals['_VOICEASSISTANTREQUEST']._serialized_start=23134
  _globals['_VOICEASSISTANTREQUEST']._serialized_end=23322
  _globals['_VOICEASSISTANTRESPONSE']._serialized_start=23324
  _globals['_VOICEASSISTANTRESPONSE']._serialized_end=23407
  _globals['_VOICEASSISTANTEVENTDATA']._serialized_start=23409
  _globals['_VOICEASSISTANTEVENTDATA']._serialized_end=23463
  _globals['_VOICEASSISTANTEVENTRESPONSE']._serialized_start=23466
  _globals['_VOICEASSISTANTEVENTRESPONSE']._serialized_end=23607
  _globals['_VOICEASSISTANTAUDIO']._serialized_start=23609
  _globals['_VOICEASSISTANTAUDIO']._serialized_end=23693
  _globals['_VOICEASSISTANTTIMEREVENTRESPONSE']._serialized_start=23696
  _globals['_VOICEASSISTANTTIMEREVENTRESPONSE']._serialized_end=23903
  _globals['_VOICEASSISTANTANNOUNCEREQUEST']._serialized_start=23906
  _globals['_VOICEASSISTANTANNOUNCEREQUEST']._serialized_end=24057
  _globals['_VOICEASSISTANTANNOUNCEFINISHED']._serialized_start=24059
  _globals['_VOICEASSISTANTANNOUNCEFINISHED']._serialized_end=24138
  _globals['_VOICEASSISTANTWAKEWORD']._serialized_start=24140
  _globals['_VOICEASSISTANTWAKEWORD']._serialized_end=24222
  _globals['_VOICEASSISTANTEXTERNALWAKEWORD']._serialized_start=24225
  _globals['_VOICEASSISTANTEXTERNALWAKEWORD']._serialized_end=24388
  _globals['_VOICEASSISTANTCONFIGURATIONREQUEST']._serialized_start=24391
  _globals['_VOICEASSISTANTCONFIGURATIONREQUEST']._serialized_end=24519
  _globals['_VOICEASSISTANTCONFIGURATIONRESPONSE']._serialized_start=24522
  _globals['_VOICEASSISTANTCONFIGURATIONRESPONSE']._serialized_end=24719
  _globals['_VOICEASSISTANTSETCONFIGURATION']._serialized_start=24721
  _globals['_VOICEASSISTANTSETCONFIGURATION']._serialized_end=24810
  _globals['_LISTENTITIESALARMCONTROLPANELRESPONSE']._serialized_start=24813
  _globals['_LISTENTITIESALARMCONTROLPANELRESPONSE']._serialized_end=25192
  _globals['_ALARMCONTROLPANELSTATERESPONSE']._serialized_start=25195
  _globals['_ALARMCONTROLPANELSTATERESPONSE']._serialized_end=25386
  _globals['_ALARMCONTROLPANELCOMMANDREQUEST']._serialized_start=25389
  _globals['_ALARMCONTROLPANELCOMMANDREQUEST']._serialized_end=25598
  _globals['_LISTENTITIESTEXTRESPONSE']._serialized_start=25601
  _globals['_LISTENTITIESTEXTRESPONSE']._serialized_end=25953
  _globals['_TEXTSTATERESPONSE']._serialized_start=25956
  _globals['_TEXTSTATERESPONSE']._serialized_end=26117
  _globals['_TEXTCOMMANDREQUEST']._serialized_start=26120
  _globals['_TEXTCOMMANDREQUEST']._serialized_end=26253
  _globals['_LISTENTITIESDATERESPONSE']._serialized_start=26256
  _globals['_LISTENTITIESDATERESPONSE']._serialized_end=26535
  _globals['_DATESTATERESPONSE']._serialized_start=26538
  _globals['_DATESTATERESPONSE']._serialized_end=26735
  _globals['_DATECOMMANDREQUEST']._serialized_start=26738
  _globals['_DATECOMMANDREQUEST']._serialized_end=26907
  _globals['_LISTENTITIESTIMERESPONSE']._serialized_start=26910
  _globals['_LISTENTITIESTIMERESPONSE']._serialized_end=27189
  _globals['_TIMESTATERESPONSE']._serialized_start=27192
  _globals['_TIMESTATERESPONSE']._serialized_end=27393
  _globals['_TIMECOMMANDREQUEST']._serialized_start=27396
  _globals['_TIMECOMMANDREQUEST']._serialized_end=27569
  _globals['_LISTENTITIESEVENTRESPONSE']._serialized_start=27572
  _globals['_LISTENTITIESEVENTRESPONSE']._serialized_end=27918
  _globals['_EVENTRESPONSE']._serialized_start=27921
  _globals['_EVENTRESPONSE']._serialized_end=28058
  _globals['_LISTENTITIESVALVERESPONSE']._serialized_start=28061
  _globals['_LISTENTITIESVALVERESPONSE']._serialized_end=28428
  _globals['_VALVESTATERESPONSE']._serialized_start=28431
  _globals['_VALVESTATERESPONSE']._serialized_end=28618
  _globals['_VALVECOMMANDREQUEST']._serialized_start=28621
  _globals['_VALVECOMMANDREQUEST']._serialized_end=28795
  _globals['_LISTENTITIESDATETIMERESPONSE']._serialized_start=28798
  _globals['_LISTENTITIESDATETIMERESPONSE']._serialized_end=29085
  _globals['_DATETIMESTATERESPONSE']._serialized_start=29088
  _globals['_DATETIMESTATERESPONSE']._serialized_end=29274
  _globals['_DATETIMECOMMANDREQUEST']._serialized_start=29277
  _globals['_DATETIMECOMMANDREQUEST']._serialized_end=29435
  _globals['_LISTENTITIESUPDATERESPONSE']._serialized_start=29438
  _globals['_LISTENTITIESUPDATERESPONSE']._serialized_end=29734
  _globals['_UPDATESTATERESPONSE']._serialized_start=29737
  _globals['_UPDATESTATERESPONSE']._serialized_end=30058
  _globals['_UPDATECOMMANDREQUEST']._serialized_start=30061
  _globals['_UPDATECOMMANDREQUEST']._serialized_end=30216
  _globals['_ZWAVEPROXYFRAME']._serialized_start=30218
  _globals['_ZWAVEPROXYFRAME']._serialized_end=30279
  _globals['_ZWAVEPROXYREQUEST']._serialized_start=30281
  _globals['_ZWAVEPROXYREQUEST']._serialized_end=30379
  _globals['_LISTENTITIESINFRAREDRESPONSE']._serialized_start=30382
  _globals['_LISTENTITIESINFRAREDRESPONSE']._serialized_end=30677
  _globals['_INFRAREDRFTRANSMITRAWTIMINGSREQUEST']._serialized_start=30680
  _globals['_INFRAREDRFTRANSMITRAWTIMINGSREQUEST']._serialized_end=30866
  _globals['_INFRAREDRFRECEIVEEVENT']._serialized_start=30869
  _globals['_INFRAREDRFRECEIVEEVENT']._serialized_end=31016
  _globals['_SERIALPROXYCONFIGUREREQUEST']._serialized_start=31019
  _globals['_SERIALPROXYCONFIGUREREQUEST']._serialized_end=31208
  _globals['_SERIALPROXYDATARECEIVED']._serialized_start=31210
  _globals['_SERIALPROXYDATARECEIVED']._serialized_end=31298
  _globals['_SERIALPROXYWRITEREQUEST']._serialized_start=31300
  _globals['_SERIALPROXYWRITEREQUEST']._serialized_end=31388
  _globals['_SERIALPROXYSETMODEMPINSREQUEST']._serialized_start=31390
  _globals['_SERIALPROXYSETMODEMPINSREQUEST']._serialized_end=31489
  _globals['_SERIALPROXYGETMODEMPINSREQUEST']._serialized_start=31491
  _globals['_SERIALPROXYGETMODEMPINSREQUEST']._serialized_end=31569
  _globals['_SERIALPROXYGETMODEMPINSRESPONSE']._serialized_start=31571
  _globals['_SERIALPROXYGETMODEMPINSRESPONSE']._serialized_end=31671
  _globals['_SERIALPROXYREQUEST']._serialized_start=31673
  _globals['_SERIALPROXYREQUEST']._serialized_end=31778
  _globals['_SERIALPROXYREQUESTRESPONSE']._serialized_start=31781
  _globals['_SERIALPROXYREQUESTRESPONSE']._serialized_end=31953
  _globals['_BLUETOOTHSETCONNECTIONPARAMSREQUEST']._serialized_start=31956
  _globals['_BLUETOOTHSETCONNECTIONPARAMSREQUEST']._serialized_end=32119
  _globals['_BLUETOOTHSETCONNECTIONPARAMSRESPONSE']._serialized_start=32121
  _globals['_BLUETOOTHSETCONNECTIONPARAMSRESPONSE']._serialized_end=32222
  _globals['_APICONNECTION']._serialized_start=40118
  _globals['_APICONNECTION']._serialized_end=43580
# @@protoc_insertion_point(module_scope)
